@@ -14,7 +14,7 @@
  * limitations under the License.
  *
  * For more information : contact@centreon.com
-*/
+ */
 #include "com/centreon/broker/storage/conflict_manager.hh"
 
 #include <cassert>
@@ -22,18 +22,19 @@
 #include "bbdo/events.hh"
 #include "bbdo/storage/index_mapping.hh"
 #include "com/centreon/broker/config/applier/init.hh"
-#include "com/centreon/broker/log_v2.hh"
-#include "com/centreon/broker/misc/perfdata.hh"
 #include "com/centreon/broker/multiplexing/publisher.hh"
 #include "com/centreon/broker/neb/events.hh"
 #include "com/centreon/broker/sql/mysql_result.hh"
 #include "com/centreon/broker/storage/internal.hh"
+#include "com/centreon/common/perfdata.hh"
 #include "com/centreon/exceptions/msg_fmt.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::exceptions;
 using namespace com::centreon::broker;
 using namespace com::centreon::broker::database;
 using namespace com::centreon::broker::storage;
+using log_v2 = com::centreon::common::log_v2::log_v2;
 
 const std::array<std::string, 5> conflict_manager::metric_type_name{
     "GAUGE", "COUNTER", "DERIVE", "ABSOLUTE", "AUTOMATIC"};
@@ -71,7 +72,7 @@ void (conflict_manager::*const conflict_manager::_neb_processing_table[])(
     &conflict_manager::_process_service_group_member,
     &conflict_manager::_process_service,
     &conflict_manager::_process_service_status,
-    &conflict_manager::_process_instance_configuration,
+    nullptr,
     &conflict_manager::_process_responsive_instance,
     nullptr,
     nullptr,
@@ -100,9 +101,11 @@ conflict_manager::conflict_manager(database_config const& dbcfg,
       _center{stats::center::instance_ptr()},
       _stats{_center->register_conflict_manager()},
       _ref_count{0},
-      _group_clean_timer{pool::io_context()},
-      _oldest_timestamp{std::numeric_limits<time_t>::max()} {
-  log_v2::sql()->debug("conflict_manager: class instanciation");
+      _group_clean_timer{com::centreon::common::pool::io_context()},
+      _oldest_timestamp{std::numeric_limits<time_t>::max()},
+      _logger_sql{log_v2::instance().get(log_v2::SQL)},
+      _logger_storage{log_v2::instance().get(log_v2::PERFDATA)} {
+  _logger_sql->debug("conflict_manager: class instanciation");
   _center->update(&ConflictManagerStats::set_loop_timeout, _stats,
                   _loop_timeout);
   _center->update(&ConflictManagerStats::set_max_pending_events, _stats,
@@ -110,7 +113,7 @@ conflict_manager::conflict_manager(database_config const& dbcfg,
 }
 
 conflict_manager::~conflict_manager() {
-  log_v2::sql()->debug("conflict_manager: destruction");
+  _logger_sql->debug("conflict_manager: destruction");
   std::lock_guard<std::mutex> l(_group_clean_timer_m);
   _group_clean_timer.cancel();
 }
@@ -132,7 +135,9 @@ bool conflict_manager::init_storage(bool store_in_db,
                                     uint32_t rrd_len,
                                     uint32_t interval_length,
                                     const database_config& dbcfg) {
-  log_v2::sql()->debug("conflict_manager: storage stream initialization");
+  log_v2::instance()
+      .get(log_v2::CORE)
+      ->debug("conflict_manager: storage stream initialization");
   int count;
 
   std::unique_lock<std::mutex> lk(_init_m);
@@ -145,13 +150,18 @@ bool conflict_manager::init_storage(bool store_in_db,
         })) {
       if (_state == finished ||
           config::applier::mode == config::applier::finished) {
-        log_v2::sql()->info("Conflict manager not started because cbd stopped");
+        log_v2::instance()
+            .get(log_v2::CORE)
+            ->info("Conflict manager not started because cbd stopped");
         return false;
       }
       if (_singleton->_mysql.get_config() != dbcfg) {
-        log_v2::sql()->error(
-            "Conflict manager: storage and sql streams do not have the same "
-            "database configuration");
+        log_v2::instance()
+            .get(log_v2::CORE)
+            ->error(
+                "Conflict manager: storage and sql streams do not have the "
+                "same "
+                "database configuration");
         return false;
       }
       std::lock_guard<std::mutex> lck(_singleton->_loop_m);
@@ -169,17 +179,22 @@ bool conflict_manager::init_storage(bool store_in_db,
       _singleton->_thread =
           std::thread(&conflict_manager::_callback, _singleton);
       pthread_setname_np(_singleton->_thread.native_handle(), "conflict_mngr");
-      log_v2::sql()->info("Conflict manager running");
+      log_v2::instance().get(log_v2::CORE)->info("Conflict manager running");
       return true;
     }
-    log_v2::sql()->info(
-        "conflict_manager: Waiting for the sql stream initialization for {} "
-        "seconds",
-        count);
+    log_v2::instance()
+        .get(log_v2::CORE)
+        ->info(
+            "conflict_manager: Waiting for the sql stream initialization for "
+            "{} "
+            "seconds",
+            count);
   }
-  log_v2::sql()->error(
-      "conflict_manager: not initialized after 60s. Probably "
-      "an issue in the sql output configuration.");
+  log_v2::instance()
+      .get(log_v2::CORE)
+      ->error(
+          "conflict_manager: not initialized after 60s. Probably "
+          "an issue in the sql output configuration.");
   return false;
 }
 
@@ -201,7 +216,9 @@ bool conflict_manager::init_storage(bool store_in_db,
 bool conflict_manager::init_sql(database_config const& dbcfg,
                                 uint32_t loop_timeout,
                                 uint32_t instance_timeout) {
-  log_v2::sql()->debug("conflict_manager: sql stream initialization");
+  log_v2::instance()
+      .get(log_v2::CORE)
+      ->debug("conflict_manager: sql stream initialization");
   std::lock_guard<std::mutex> lk(_init_m);
   _singleton = new conflict_manager(dbcfg, loop_timeout, instance_timeout);
   if (!_singleton) {
@@ -341,7 +358,7 @@ void conflict_manager::_load_caches() {
           .special = res.value_as_u32(6) == 2};
       uint32_t host_id(res.value_as_u32(1));
       uint32_t service_id(res.value_as_u32(2));
-      log_v2::perfdata()->debug(
+      _logger_storage->debug(
           "storage: loaded index {} of ({}, {}) with rrd_len={}", info.index_id,
           host_id, service_id, info.rrd_retention);
       _index_cache[{host_id, service_id}] = std::move(info);
@@ -442,7 +459,7 @@ void conflict_manager::update_metric_info_cache(uint64_t index_id,
                                                 short metric_type) {
   auto it = _metric_cache.find({index_id, metric_name});
   if (it != _metric_cache.end()) {
-    log_v2::perfdata()->info(
+    _logger_storage->info(
         "conflict_manager: updating metric '{}' of id {} at index {} to "
         "metric_type {}",
         metric_name, metric_id, index_id, metric_type_name[metric_type]);
@@ -466,7 +483,7 @@ void conflict_manager::_callback() {
   try {
     _load_caches();
   } catch (std::exception const& e) {
-    log_v2::sql()->error("error while loading caches: {}", e.what());
+    _logger_sql->error("error while loading caches: {}", e.what());
     _broken = true;
   }
 
@@ -494,7 +511,7 @@ void conflict_manager::_callback() {
         /* Time to send logs to database */
         _insert_logs();
 
-        log_v2::sql()->trace(
+        _logger_sql->trace(
             "conflict_manager: main loop initialized with a timeout of {} "
             "seconds.",
             _loop_timeout);
@@ -508,7 +525,7 @@ void conflict_manager::_callback() {
             _check_deleted_index();
             time_to_deleted_index += std::chrono::minutes(5);
           } catch (std::exception const& e) {
-            log_v2::sql()->error(
+            _logger_sql->error(
                 "conflict_manager: error while checking deleted indexes: {}",
                 e.what());
             _broken = true;
@@ -618,8 +635,8 @@ void conflict_manager::_callback() {
               if (fn)
                 (this->*fn)(tpl);
               else {
-                log_v2::sql()->warn("SQL: no function defined for event {}:{}",
-                                    cat, elem);
+                _logger_sql->warn("SQL: no function defined for event {}:{}",
+                                  cat, elem);
                 *std::get<2>(tpl) = true;
               }
             } else if (std::get<1>(tpl) == storage && cat == io::neb &&
@@ -633,8 +650,13 @@ void conflict_manager::_callback() {
                        type == make_type(io::bbdo, bbdo::de_remove_graphs)) {
               remove_graphs(d);
               *std::get<2>(tpl) = true;
+            } else if (std::get<1>(tpl) == sql &&
+                       type == make_type(io::local, local::de_pb_stop)) {
+              _logger_sql->info("poller stopped...");
+              process_stop(d);
+              *std::get<2>(tpl) = true;
             } else {
-              log_v2::sql()->trace(
+              _logger_sql->trace(
                   "conflict_manager: event of type {} from channel '{}' thrown "
                   "away ; no need to "
                   "store it in the database.",
@@ -680,14 +702,14 @@ void conflict_manager::_callback() {
             }
           }
         }
-        log_v2::sql()->debug("{} new events to treat", count);
+        _logger_sql->debug("{} new events to treat", count);
         /* Here, just before looping, we commit. */
         _finish_actions();
         if (_fifo.get_pending_elements() == 0)
-          log_v2::sql()->debug(
+          _logger_sql->debug(
               "conflict_manager: acknowledgement - no pending events");
         else
-          log_v2::sql()->debug(
+          _logger_sql->debug(
               "conflict_manager: acknowledgement - still {} not acknowledged",
               _fifo.get_pending_elements());
 
@@ -700,8 +722,8 @@ void conflict_manager::_callback() {
                       _fifo.get_timeline(storage).size());
       }
     } catch (std::exception const& e) {
-      log_v2::sql()->error("conflict_manager: error in the main loop: {}",
-                           e.what());
+      _logger_sql->error("conflict_manager: error in the main loop: {}",
+                         e.what());
       if (strstr(e.what(), "server has gone away")) {
         // The case where we must restart the connector.
         _broken = true;
@@ -712,7 +734,7 @@ void conflict_manager::_callback() {
   if (_broken) {
     std::unique_lock<std::mutex> lk(_loop_m);
     /* Let's wait for the end */
-    log_v2::sql()->info(
+    _logger_sql->info(
         "conflict_manager: waiting for the end of the conflict manager main "
         "loop.");
     _loop_cv.wait(lk, [this]() { return !_exit; });
@@ -748,7 +770,7 @@ int32_t conflict_manager::send_event(conflict_manager::stream_type c,
   if (_broken)
     throw msg_fmt("conflict_manager: events loop interrupted");
 
-  log_v2::sql()->trace(
+  _logger_sql->trace(
       "conflict_manager: send_event category:{}, element:{} from {}",
       e->type() >> 16, e->type() & 0xffff, c == 0 ? "sql" : "storage");
 
@@ -803,15 +825,15 @@ void conflict_manager::_finish_action(int32_t conn, uint32_t action) {
  *  events.
  */
 void conflict_manager::_finish_actions() {
-  log_v2::sql()->trace("conflict_manager: finish actions");
+  _logger_sql->trace("conflict_manager: finish actions");
   _mysql.commit();
   std::fill(_action.begin(), _action.end(), actions::none);
 
   _fifo.clean(sql);
   _fifo.clean(storage);
 
-  log_v2::sql()->debug("conflict_manager: still {} not acknowledged",
-                       _fifo.get_pending_elements());
+  _logger_sql->debug("conflict_manager: still {} not acknowledged",
+                     _fifo.get_pending_elements());
 }
 
 /**
@@ -891,29 +913,29 @@ nlohmann::json conflict_manager::get_statistics() {
  * @brief Delete the conflict_manager singleton.
  */
 int32_t conflict_manager::unload(stream_type type) {
+  auto logger = _singleton->_logger_sql;
   if (!_singleton) {
-    log_v2::sql()->info("conflict_manager: already unloaded.");
+    logger->info("conflict_manager: already unloaded.");
     return 0;
   } else {
     uint32_t count = --_singleton->_ref_count;
     int retval;
     if (count == 0) {
-      __exit();
-      retval = _fifo.get_acks(type);
+      _singleton->__exit();
+      retval = _singleton->_fifo.get_acks(type);
       {
-        std::lock_guard<std::mutex> lck(_init_m);
+        std::lock_guard<std::mutex> lck(_singleton->_init_m);
         _state = finished;
         delete _singleton;
         _singleton = nullptr;
       }
-      log_v2::sql()->info(
-          "conflict_manager: no more user of the conflict manager.");
+      logger->info("conflict_manager: no more user of the conflict manager.");
     } else {
-      log_v2::sql()->info(
+      logger->info(
           "conflict_manager: still {} stream{} using the conflict manager.",
           count, count > 1 ? "s" : "");
-      retval = _fifo.get_acks(type);
-      log_v2::sql()->info(
+      retval = _singleton->_fifo.get_acks(type);
+      logger->info(
           "conflict_manager: still {} events handled but not acknowledged.",
           retval);
     }
@@ -921,13 +943,50 @@ int32_t conflict_manager::unload(stream_type type) {
   }
 }
 
+/**
+ * @brief Function called when a poller is disconnected from Broker. It cleans
+ * hosts/services and instances in the storage database.
+ *
+ * @param d A pb_stop event with the instance ID.
+ */
+void conflict_manager::process_stop(const std::shared_ptr<io::data>& d) {
+  auto& stop = static_cast<local::pb_stop*>(d.get())->obj();
+  int32_t conn = _mysql.choose_connection_by_instance(stop.poller_id());
+  _finish_action(-1, actions::hosts | actions::acknowledgements |
+                         actions::modules | actions::downtimes |
+                         actions::comments | actions::servicegroups |
+                         actions::hostgroups | actions::service_dependencies |
+                         actions::host_dependencies);
+
+  // Log message.
+  _logger_sql->info("SQL: Disabling poller (id: {}, running: no)",
+                    stop.poller_id());
+
+  // Clean tables.
+  _clean_tables(stop.poller_id());
+
+  // Processing.
+  if (_is_valid_poller(stop.poller_id())) {
+    // Prepare queries.
+    if (!_instance_insupdate.prepared()) {
+      std::string query(fmt::format(
+          "UPDATE instances SET end_time={}, running=0 WHERE instance_id={}",
+          time(nullptr), stop.poller_id()));
+      _mysql.run_query(query, database::mysql_error::clean_hosts_services,
+                       conn);
+      _add_action(conn, actions::instances);
+    }
+  }
+}
+
 /**
  * @brief process a remove graphs message.
  *
  * @param d The BBDO message with all the metrics/indexes to remove.
  */
 void conflict_manager::remove_graphs(const std::shared_ptr<io::data>& d) {
-  asio::post(pool::instance().io_context(), [this, data = d] {
+  asio::post(com::centreon::common::pool::instance().io_context(), [this,
+                                                                    data = d] {
     mysql ms(_mysql.get_config());
     const bbdo::pb_remove_graphs& ids =
         *static_cast<const bbdo::pb_remove_graphs*>(data.get());
@@ -978,7 +1037,7 @@ void conflict_manager::remove_graphs(const std::shared_ptr<io::data>& d) {
         }
       }
     } catch (const std::exception& e) {
-      log_v2::sql()->error(
+      _logger_sql->error(
           "could not query index / metrics table(s) to get index to delete: "
           "{} ",
           e.what());
@@ -986,14 +1045,14 @@ void conflict_manager::remove_graphs(const std::shared_ptr<io::data>& d) {
 
     std::string mids_str{fmt::format("{}", fmt::join(metrics_to_delete, ","))};
     if (!metrics_to_delete.empty()) {
-      log_v2::sql()->info("metrics {} erased from database", mids_str);
+      _logger_sql->info("metrics {} erased from database", mids_str);
       ms.run_query(
           fmt::format("DELETE FROM metrics WHERE metric_id in ({})", mids_str),
           database::mysql_error::delete_metric);
     }
     std::string ids_str{fmt::format("{}", fmt::join(indexes_to_delete, ","))};
     if (!indexes_to_delete.empty()) {
-      log_v2::sql()->info("indexes {} erased from database", ids_str);
+      _logger_sql->info("indexes {} erased from database", ids_str);
       ms.run_query(
           fmt::format("DELETE FROM index_data WHERE id in ({})", ids_str),
           database::mysql_error::delete_index);
@@ -1007,7 +1066,7 @@ void conflict_manager::remove_graphs(const std::shared_ptr<io::data>& d) {
         rmg->mut_obj().add_index_ids(i);
       multiplexing::publisher().write(rmg);
     } else
-      log_v2::sql()->info(
+      _logger_sql->info(
           "metrics {} and indexes {} do not appear in the storage database",
           fmt::join(ids.obj().metric_ids(), ","),
           fmt::join(ids.obj().index_ids(), ","));
