@@ -1,23 +1,22 @@
-/*
-** Copyright 2019-2022 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2019-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 #include <fmt/format.h>
 
-#include "com/centreon/broker/log_v2.hh"
 #include "com/centreon/broker/misc/string.hh"
 #include "com/centreon/broker/neb/events.hh"
 #include "com/centreon/broker/sql/mysql_result.hh"
@@ -50,7 +49,7 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
 
   _finish_action(-1, -1);
   int32_t conn = _mysql.choose_connection_by_instance(instance_id);
-  log_v2::sql()->debug(
+  _logger_sql->debug(
       "conflict_manager: disable hosts and services (instance_id: {})",
       instance_id);
   /* Disable hosts and services. */
@@ -62,7 +61,7 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::hosts);
 
   /* Remove host group memberships. */
-  log_v2::sql()->debug(
+  _logger_sql->debug(
       "conflict_manager: remove host group memberships (instance_id: {})",
       instance_id);
   query = fmt::format(
@@ -73,7 +72,7 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::hostgroups);
 
   /* Remove service group memberships */
-  log_v2::sql()->debug(
+  _logger_sql->debug(
       "conflict_manager: remove service group memberships (instance_id: {})",
       instance_id);
   query = fmt::format(
@@ -86,7 +85,7 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::servicegroups);
 
   /* Remove host dependencies. */
-  log_v2::sql()->debug(
+  _logger_sql->debug(
       "conflict_manager: remove host dependencies (instance_id: {})",
       instance_id);
   query = fmt::format(
@@ -98,8 +97,8 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::host_dependencies);
 
   /* Remove host parents. */
-  log_v2::sql()->debug(
-      "conflict_manager: remove host parents (instance_id: {})", instance_id);
+  _logger_sql->debug("conflict_manager: remove host parents (instance_id: {})",
+                     instance_id);
   query = fmt::format(
       "DELETE hhp FROM hosts_hosts_parents AS hhp INNER JOIN hosts as h ON "
       "hhp.child_id=h.host_id OR hhp.parent_id=h.host_id WHERE "
@@ -109,7 +108,7 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::host_parents);
 
   /* Remove service dependencies. */
-  log_v2::sql()->debug(
+  _logger_sql->debug(
       "conflict_manager: remove service dependencies (instance_id: {})",
       instance_id);
   query = fmt::format(
@@ -126,15 +125,15 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::service_dependencies);
 
   /* Remove list of modules. */
-  log_v2::sql()->debug("SQL: remove list of modules (instance_id: {})",
-                       instance_id);
+  _logger_sql->debug("SQL: remove list of modules (instance_id: {})",
+                     instance_id);
   query = fmt::format("DELETE FROM modules WHERE instance_id={}", instance_id);
   _mysql.run_query(query, database::mysql_error::clean_modules, conn);
   _add_action(conn, actions::modules);
 
   // Cancellation of downtimes.
-  log_v2::sql()->debug("SQL: Cancellation of downtimes (instance_id: {})",
-                       instance_id);
+  _logger_sql->debug("SQL: Cancellation of downtimes (instance_id: {})",
+                     instance_id);
   query = fmt::format(
       "UPDATE downtimes SET cancelled=1 WHERE actual_end_time IS NULL AND "
       "cancelled=0 "
@@ -145,8 +144,8 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
   _add_action(conn, actions::downtimes);
 
   // Remove comments.
-  log_v2::sql()->debug("conflict_manager: remove comments (instance_id: {})",
-                       instance_id);
+  _logger_sql->debug("conflict_manager: remove comments (instance_id: {})",
+                     instance_id);
 
   query = fmt::format(
       "UPDATE comments SET deletion_time={} WHERE instance_id={} AND "
@@ -159,8 +158,8 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
 
   // Remove custom variables. No need to choose the good instance, there are
   // no constraint between custom variables and instances.
-  log_v2::sql()->debug("Removing custom variables (instance_id: {})",
-                       instance_id);
+  _logger_sql->debug("Removing custom variables (instance_id: {})",
+                     instance_id);
   query = fmt::format(
       "DELETE cv FROM customvariables AS cv INNER JOIN hosts AS h ON "
       "cv.host_id = h.host_id WHERE h.instance_id={}",
@@ -182,7 +181,7 @@ void conflict_manager::_clean_tables(uint32_t instance_id) {
 void conflict_manager::_clean_group_table() {
   int32_t conn = _mysql.choose_best_connection(-1);
   /* Remove host groups. */
-  log_v2::sql()->debug("conflict_manager: remove empty host groups ");
+  _logger_sql->debug("conflict_manager: remove empty host groups ");
   _mysql.run_query(
       "DELETE hg FROM hostgroups AS hg LEFT JOIN hosts_hostgroups AS hhg ON "
       "hg.hostgroup_id=hhg.hostgroup_id WHERE hhg.hostgroup_id IS NULL",
@@ -190,7 +189,7 @@ void conflict_manager::_clean_group_table() {
   _add_action(conn, actions::hostgroups);
 
   /* Remove service groups. */
-  log_v2::sql()->debug("conflict_manager: remove empty service groups");
+  _logger_sql->debug("conflict_manager: remove empty service groups");
 
   _mysql.run_query(
       "DELETE sg FROM servicegroups AS sg LEFT JOIN services_servicegroups as "
@@ -204,7 +203,7 @@ void conflict_manager::_clean_group_table() {
  *  Update all the hosts and services of unresponsive instances.
  */
 void conflict_manager::_update_hosts_and_services_of_unresponsive_instances() {
-  log_v2::sql()->debug("conflict_manager: checking for outdated instances");
+  _logger_sql->debug("conflict_manager: checking for outdated instances");
 
   /* Don't do anything if timeout is deactivated. */
   if (_instance_timeout == 0)
@@ -272,8 +271,9 @@ void conflict_manager::_update_hosts_and_services_of_instance(uint32_t id,
         "UPDATE hosts AS h LEFT JOIN services AS s ON h.host_id=s.host_id "
         "SET h.real_state=h.state,s.real_state=s.state,h.state={},s.state={} "
         "WHERE h.instance_id={}",
-        com::centreon::engine::host::state_unreachable,
-        com::centreon::engine::service::state_unknown, id);
+        static_cast<uint32_t>(com::centreon::engine::host::state_unreachable),
+        static_cast<uint32_t>(com::centreon::engine::service::state_unknown),
+        id);
     _mysql.run_query(query, database::mysql_error::restore_instances, conn);
     _add_action(conn, actions::hosts);
   }
@@ -317,7 +317,7 @@ bool conflict_manager::_is_valid_poller(uint32_t instance_id) {
   bool deleted = false;
   if (_cache_deleted_instance_id.find(instance_id) !=
       _cache_deleted_instance_id.end()) {
-    log_v2::sql()->info(
+    _logger_sql->info(
         "conflict_manager: discarding some event related to a deleted poller "
         "({})",
         instance_id);
@@ -362,7 +362,7 @@ void conflict_manager::_process_acknowledgement(
       *static_cast<neb::acknowledgement const*>(d.get());
 
   // Log message.
-  log_v2::sql()->info(
+  _logger_sql->info(
       "processing acknowledgement event (poller: {}, host: {}, service: {}, "
       "entry time: {}, deletion time: {})",
       ack.poller_id, ack.host_id, ack.service_id, ack.entry_time,
@@ -409,8 +409,8 @@ void conflict_manager::_process_comment(
   int32_t conn = _mysql.choose_connection_by_instance(cmmnt.poller_id);
 
   // Log message.
-  log_v2::sql()->info("SQL: processing comment of poller {} on ({}, {})",
-                      cmmnt.poller_id, cmmnt.host_id, cmmnt.service_id);
+  _logger_sql->info("SQL: processing comment of poller {} on ({}, {})",
+                    cmmnt.poller_id, cmmnt.host_id, cmmnt.service_id);
 
   // Prepare queries.
   if (!_comment_insupdate.prepared()) {
@@ -481,8 +481,8 @@ void conflict_manager::_process_custom_variable(
     int conn = special_conn::custom_variable % _mysql.connections_count();
     _finish_action(-1, actions::custom_variables);
 
-    log_v2::sql()->info("SQL: disabling custom variable '{}' of ({}, {})",
-                        cv.name, cv.host_id, cv.service_id);
+    _logger_sql->info("SQL: disabling custom variable '{}' of ({}, {})",
+                      cv.name, cv.host_id, cv.service_id);
     _custom_variable_delete.bind_value_as_i32_k(":host_id", cv.host_id);
     _custom_variable_delete.bind_value_as_i32_k(":service_id", cv.service_id);
     _custom_variable_delete.bind_value_as_str_k(":name", cv.name);
@@ -521,8 +521,8 @@ void conflict_manager::_process_custom_variable_status(
                       cv.value, get_centreon_storage_customvariables_col_size(
                                     centreon_storage_customvariables_value))));
 
-  log_v2::sql()->info("SQL: updating custom variable '{}' of ({}, {})", cv.name,
-                      cv.host_id, cv.service_id);
+  _logger_sql->info("SQL: updating custom variable '{}' of ({}, {})", cv.name,
+                    cv.host_id, cv.service_id);
 }
 
 /**
@@ -539,7 +539,7 @@ void conflict_manager::_process_downtime(
   const neb::downtime& dd = *static_cast<const neb::downtime*>(d.get());
 
   // Log message.
-  log_v2::sql()->info(
+  _logger_sql->info(
       "SQL: processing downtime event (poller: {}"
       ", host: {}, service: {}, start time: {}, end_time: {}"
       ", actual start time: {}"
@@ -605,9 +605,8 @@ void conflict_manager::_process_host_check(
       hc.next_check >= now - 5 * 60 ||  // - normal case
       !hc.next_check) {                 // - initial state
     // Apply to DB.
-    log_v2::sql()->info(
-        "SQL: processing host check event (host: {}, command: {}", hc.host_id,
-        hc.command_line);
+    _logger_sql->info("SQL: processing host check event (host: {}, command: {}",
+                      hc.host_id, hc.command_line);
 
     // Prepare queries.
     if (!_host_check_update.prepared()) {
@@ -639,7 +638,7 @@ void conflict_manager::_process_host_check(
     }
   } else
     // Do nothing.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: not processing host check event (host: {}, command: {}, check "
         "type: {}, next check: {}, now: {})",
         hc.host_id, hc.command_line, hc.check_type, hc.next_check, now);
@@ -668,8 +667,8 @@ void conflict_manager::_process_host_dependency(
 
   // Insert/Update.
   if (hd.enabled) {
-    log_v2::sql()->info("SQL: enabling host dependency of {} on {}",
-                        hd.dependent_host_id, hd.host_id);
+    _logger_sql->info("SQL: enabling host dependency of {} on {}",
+                      hd.dependent_host_id, hd.host_id);
 
     // Prepare queries.
     if (!_host_dependency_insupdate.prepared()) {
@@ -688,8 +687,8 @@ void conflict_manager::_process_host_dependency(
   }
   // Delete.
   else {
-    log_v2::sql()->info("SQL: removing host dependency of {} on {}",
-                        hd.dependent_host_id, hd.host_id);
+    _logger_sql->info("SQL: removing host dependency of {} on {}",
+                      hd.dependent_host_id, hd.host_id);
     std::string query(fmt::format(
         "DELETE FROM hosts_hosts_dependencies WHERE dependent_host_id={}"
         " AND host_id={}",
@@ -717,8 +716,8 @@ void conflict_manager::_process_host_group(
   neb::host_group const& hg{*static_cast<neb::host_group const*>(d.get())};
 
   if (hg.enabled) {
-    log_v2::sql()->info("SQL: enabling host group {} ('{}' on instance {})",
-                        hg.id, hg.name, hg.poller_id);
+    _logger_sql->info("SQL: enabling host group {} ('{}' on instance {})",
+                      hg.id, hg.name, hg.poller_id);
     _prepare_hg_insupdate_statement();
 
     _host_group_insupdate << hg;
@@ -729,8 +728,8 @@ void conflict_manager::_process_host_group(
   }
   // Delete group.
   else {
-    log_v2::sql()->info("SQL: disabling host group {} ('{}' on instance {})",
-                        hg.id, hg.name, hg.poller_id);
+    _logger_sql->info("SQL: disabling host group {} ('{}' on instance {})",
+                      hg.id, hg.name, hg.poller_id);
 
     // Delete group members.
     {
@@ -765,7 +764,7 @@ void conflict_manager::_process_host_group_member(
 
   if (hgm.enabled) {
     // Log message.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: enabling membership of host {} to host group {} on instance {}",
         hgm.host_id, hgm.group_id, hgm.poller_id);
 
@@ -782,7 +781,7 @@ void conflict_manager::_process_host_group_member(
     /* If the group does not exist, we create it. */
     if (_cache_host_instance[hgm.host_id]) {
       if (_hostgroup_cache.find(hgm.group_id) == _hostgroup_cache.end()) {
-        log_v2::sql()->error(
+        _logger_sql->error(
             "SQL: host group {} does not exist - insertion before insertion of "
             "members",
             hgm.group_id);
@@ -806,7 +805,7 @@ void conflict_manager::_process_host_group_member(
                            conn);
       _add_action(conn, actions::hostgroups);
     } else
-      log_v2::sql()->error(
+      _logger_sql->error(
           "SQL: host with host_id = {} does not exist - unable to store "
           "unexisting host in a hostgroup. You should restart centengine.",
           hgm.host_id);
@@ -814,7 +813,7 @@ void conflict_manager::_process_host_group_member(
   // Delete.
   else {
     // Log message.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: disabling membership of host {} to host group {} on instance {}",
         hgm.host_id, hgm.group_id, hgm.poller_id);
 
@@ -850,7 +849,7 @@ void conflict_manager::_process_host(
   neb::host& h = *static_cast<neb::host*>(d.get());
 
   // Log message.
-  log_v2::sql()->debug(
+  _logger_sql->debug(
       "SQL: processing host event (poller: {}, host: {}, name: {})",
       h.poller_id, h.host_id, h.host_name);
 
@@ -882,7 +881,7 @@ void conflict_manager::_process_host(
       else
         _cache_host_instance.erase(h.host_id);
     } else
-      log_v2::sql()->trace(
+      _logger_sql->trace(
           "SQL: host '{}' of poller {} has no ID nor alias, probably bam "
           "fake host",
           h.host_name, h.poller_id);
@@ -909,8 +908,8 @@ void conflict_manager::_process_host_parent(
   // Enable parenting.
   if (hp.enabled) {
     // Log message.
-    log_v2::sql()->info("SQL: host {} is parent of host {}", hp.parent_id,
-                        hp.host_id);
+    _logger_sql->info("SQL: host {} is parent of host {}", hp.parent_id,
+                      hp.host_id);
 
     // Prepare queries.
     if (!_host_parent_insert.prepared()) {
@@ -926,8 +925,8 @@ void conflict_manager::_process_host_parent(
   }
   // Disable parenting.
   else {
-    log_v2::sql()->info("SQL: host {} is not parent of host {} anymore",
-                        hp.parent_id, hp.host_id);
+    _logger_sql->info("SQL: host {} is not parent of host {} anymore",
+                      hp.parent_id, hp.host_id);
 
     // Prepare queries.
     if (!_host_parent_delete.prepared()) {
@@ -972,7 +971,7 @@ void conflict_manager::_process_host_status(
       hs.next_check >= now - 5 * 60 ||  // - normal case
       !hs.next_check) {                 // - initial state
     // Apply to DB.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "processing host status event (host: {}, last check: {}, state ({}, "
         "{}))",
         hs.host_id, hs.last_check, hs.current_state, hs.state_type);
@@ -994,7 +993,7 @@ void conflict_manager::_process_host_status(
     _add_action(conn, actions::hosts);
   } else
     // Do nothing.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: not processing host status event (id: {}, check type: {}, last "
         "check: {}, next check: {}, now: {}, state: ({}, {}))",
         hs.host_id, hs.check_type, hs.last_check, hs.next_check, now,
@@ -1022,7 +1021,7 @@ void conflict_manager::_process_instance(
                          actions::host_dependencies);
 
   // Log message.
-  log_v2::sql()->info(
+  _logger_sql->info(
       "SQL: processing poller event (id: {}, name: {}, running: {})",
       i.poller_id, i.name, i.is_running ? "yes" : "no");
 
@@ -1068,7 +1067,7 @@ void conflict_manager::_process_instance_status(
                          actions::comments);
 
   // Log message.
-  log_v2::sql()->info(
+  _logger_sql->info(
       "SQL: processing poller status event (id: {}, last alive: {})",
       is.poller_id, is.last_alive);
 
@@ -1106,7 +1105,7 @@ void conflict_manager::_process_log(
   neb::log_entry const& le(*static_cast<neb::log_entry const*>(d.get()));
 
   // Log message.
-  log_v2::sql()->info(
+  _logger_sql->info(
       "SQL: processing log of poller '{}' generated at {} (type {})",
       le.poller_name, le.c_time, le.msg_type);
 
@@ -1164,7 +1163,7 @@ void conflict_manager::_process_service_check(
       || (sc.next_check >= now - 5 * 60) ||
       !sc.next_check) {  // - initial state
     // Apply to DB.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: processing service check event (host: {}, service: {}, command: "
         "{})",
         sc.host_id, sc.service_id, sc.command_line);
@@ -1197,14 +1196,14 @@ void conflict_manager::_process_service_check(
                              database::mysql_error::store_service_check_command,
                              conn);
       } else
-        log_v2::sql()->error(
+        _logger_sql->error(
             "SQL: host with host_id = {} does not exist - unable to store "
             "service command check of that host. You should restart centengine",
             sc.host_id);
     }
   } else
     // Do nothing.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: not processing service check event (host: {}, service: {}, "
         "command: {}, check_type: {}, next_check: {}, now: {})",
         sc.host_id, sc.service_id, sc.command_line, sc.check_type,
@@ -1234,7 +1233,7 @@ void conflict_manager::_process_service_dependency(
 
   // Insert/Update.
   if (sd.enabled) {
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: enabling service dependency of ({}, {}) on ({}, {})",
         sd.dependent_host_id, sd.dependent_service_id, sd.host_id,
         sd.service_id);
@@ -1258,7 +1257,7 @@ void conflict_manager::_process_service_dependency(
   }
   // Delete.
   else {
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: removing service dependency of ({}, {}) on ({}, {})",
         sd.dependent_host_id, sd.dependent_service_id, sd.host_id,
         sd.service_id);
@@ -1292,8 +1291,8 @@ void conflict_manager::_process_service_group(
 
   // Insert/update group.
   if (sg.enabled) {
-    log_v2::sql()->info("SQL: enabling service group {} ('{}' on instance {})",
-                        sg.id, sg.name, sg.poller_id);
+    _logger_sql->info("SQL: enabling service group {} ('{}' on instance {})",
+                      sg.id, sg.name, sg.poller_id);
     _prepare_sg_insupdate_statement();
 
     _service_group_insupdate << sg;
@@ -1304,8 +1303,8 @@ void conflict_manager::_process_service_group(
   }
   // Delete group.
   else {
-    log_v2::sql()->info("SQL: disabling service group {} ('{}' on instance {})",
-                        sg.id, sg.name, sg.poller_id);
+    _logger_sql->info("SQL: disabling service group {} ('{}' on instance {})",
+                      sg.id, sg.name, sg.poller_id);
 
     // Delete group members.
     {
@@ -1343,7 +1342,7 @@ void conflict_manager::_process_service_group_member(
 
   if (sgm.enabled) {
     // Log message.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: enabling membership of service ({}, {}) to service group {} on "
         "instance {}",
         sgm.host_id, sgm.service_id, sgm.group_id, sgm.poller_id);
@@ -1361,7 +1360,7 @@ void conflict_manager::_process_service_group_member(
 
     /* If the group does not exist, we create it. */
     if (_servicegroup_cache.find(sgm.group_id) == _servicegroup_cache.end()) {
-      log_v2::sql()->error(
+      _logger_sql->error(
           "SQL: service group {} does not exist - insertion before insertion "
           "of members",
           sgm.group_id);
@@ -1388,7 +1387,7 @@ void conflict_manager::_process_service_group_member(
   // Delete.
   else {
     // Log message.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: disabling membership of service ({}, {}) to service group {} on "
         "instance {}",
         sgm.host_id, sgm.service_id, sgm.group_id, sgm.poller_id);
@@ -1431,7 +1430,7 @@ void conflict_manager::_process_service(
         _mysql.choose_connection_by_instance(_cache_host_instance[s.host_id]);
 
     // Log message.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: processing service event (host: {}, service: {}, "
         "description: {})",
         s.host_id, s.service_id, s.service_description);
@@ -1451,12 +1450,12 @@ void conflict_manager::_process_service(
                            database::mysql_error::store_service, conn);
       _add_action(conn, actions::services);
     } else
-      log_v2::sql()->trace(
+      _logger_sql->trace(
           "SQL: service '{}' has no host ID, service ID nor hostname, probably "
           "bam fake service",
           s.service_description);
   } else
-    log_v2::sql()->error(
+    _logger_sql->error(
         "SQL: host with host_id = {} does not exist - unable to store service "
         "of that host. You should restart centengine",
         s.host_id);
@@ -1480,9 +1479,8 @@ void conflict_manager::_process_service_status(
   neb::service_status const& ss{
       *static_cast<neb::service_status const*>(d.get())};
 
-  log_v2::perfdata()->info("SQL: service status output: <<{}>>", ss.output);
-  log_v2::perfdata()->info("SQL: service status perfdata: <<{}>>",
-                           ss.perf_data);
+  _logger_storage->info("SQL: service status output: <<{}>>", ss.output);
+  _logger_storage->info("SQL: service status perfdata: <<{}>>", ss.perf_data);
 
   time_t now = time(nullptr);
   if (ss.check_type ||           // - passive result
@@ -1491,7 +1489,7 @@ void conflict_manager::_process_service_status(
       ||                         // - normal case
       ss.next_check >= now - 5 * 60 || !ss.next_check) {  // - initial state
     // Apply to DB.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: processing service status event (host: {}, service: {}, last "
         "check: {}, state ({}, {}))",
         ss.host_id, ss.service_id, ss.last_check, ss.current_state,
@@ -1515,7 +1513,7 @@ void conflict_manager::_process_service_status(
     _add_action(conn, actions::services);
   } else
     // Do nothing.
-    log_v2::sql()->info(
+    _logger_sql->info(
         "SQL: not processing service status event (host: {}, service: {}, "
         "check type: {}, last check: {}, next check: {}, now: {}, state ({}, "
         "{}))",
@@ -1524,18 +1522,6 @@ void conflict_manager::_process_service_status(
   *std::get<2>(t) = true;
 }
 
-/**
- *  Process an instance configuration event.
- *
- *  @param[in] e  Uncasted instance configuration.
- *
- * @return The number of events that can be acknowledged.
- */
-void conflict_manager::_process_instance_configuration(
-    std::tuple<std::shared_ptr<io::data>, uint32_t, bool*>& t) {
-  *std::get<2>(t) = true;
-}
-
 /**
  *  Process a responsive instance event.
  *
@@ -1548,7 +1534,7 @@ void conflict_manager::_process_responsive_instance(
 
 void conflict_manager::_process_severity(
     std::tuple<std::shared_ptr<io::data>, uint32_t, bool*>& t) {
-  log_v2::sql()->debug("SQL: process severity");
+  _logger_sql->debug("SQL: process severity");
   auto& d = std::get<0>(t);
   _finish_action(-1, actions::severities);
 
@@ -1570,7 +1556,7 @@ void conflict_manager::_process_severity(
     case Severity_Action_ADD:
       _add_action(conn, actions::severities);
       if (severity_id) {
-        log_v2::sql()->trace("SQL: add already existing severity {}", sv.id());
+        _logger_sql->trace("SQL: add already existing severity {}", sv.id());
         _severity_update.bind_value_as_u64(0, sv.id());
         _severity_update.bind_value_as_u32(1, sv.type());
         _severity_update.bind_value_as_str(2, sv.name());
@@ -1580,7 +1566,7 @@ void conflict_manager::_process_severity(
         _mysql.run_statement(_severity_update,
                              database::mysql_error::store_severity, conn);
       } else {
-        log_v2::sql()->trace("SQL: add severity {}", sv.id());
+        _logger_sql->trace("SQL: add severity {}", sv.id());
         _severity_insert.bind_value_as_u64(0, sv.id());
         _severity_insert.bind_value_as_u32(1, sv.type());
         _severity_insert.bind_value_as_str(2, sv.name());
@@ -1596,14 +1582,14 @@ void conflict_manager::_process_severity(
           severity_id = future.get();
           _severity_cache[{sv.id(), sv.type()}] = severity_id;
         } catch (const std::exception& e) {
-          log_v2::sql()->error(
+          _logger_sql->error(
               "unified sql: unable to insert new severity ({},{}): {}", sv.id(),
               sv.type(), e.what());
         }
       }
       break;
     case Severity_Action_MODIFY:
-      log_v2::sql()->trace("SQL: modify severity {}", sv.id());
+      _logger_sql->trace("SQL: modify severity {}", sv.id());
       _severity_update.bind_value_as_u64(0, sv.id());
       _severity_update.bind_value_as_u32(1, sv.type());
       _severity_update.bind_value_as_str(2, sv.name());
@@ -1615,18 +1601,18 @@ void conflict_manager::_process_severity(
                              database::mysql_error::store_severity, conn);
         _add_action(conn, actions::severities);
       } else
-        log_v2::sql()->error(
+        _logger_sql->error(
             "unified sql: unable to modify severity ({}, {}): not in cache",
             sv.id(), sv.type());
       break;
     case Severity_Action_DELETE:
-      log_v2::sql()->trace("SQL: remove severity {}: not implemented", sv.id());
+      _logger_sql->trace("SQL: remove severity {}: not implemented", sv.id());
       // FIXME DBO: Delete should be implemented later. This case is difficult
       // particularly when several pollers are running and some of them can
       // be stopped...
       break;
     default:
-      log_v2::sql()->error("Bad action in severity object");
+      _logger_sql->error("Bad action in severity object");
       break;
   }
   *std::get<2>(t) = true;
@@ -1634,7 +1620,7 @@ void conflict_manager::_process_severity(
 
 void conflict_manager::_process_tag(
     std::tuple<std::shared_ptr<io::data>, uint32_t, bool*>& t) {
-  log_v2::sql()->debug("SQL: process tag");
+  _logger_sql->debug("SQL: process tag");
   auto& d = std::get<0>(t);
   _finish_action(-1, actions::tags);
 
@@ -1655,7 +1641,7 @@ void conflict_manager::_process_tag(
   switch (tg.action()) {
     case Tag_Action_ADD:
       if (tag_id) {
-        log_v2::sql()->trace("SQL: add already existing tag {}", tg.id());
+        _logger_sql->trace("SQL: add already existing tag {}", tg.id());
         _tag_update.bind_value_as_u64(0, tg.id());
         _tag_update.bind_value_as_u32(1, tg.type());
         _tag_update.bind_value_as_str(2, tg.name());
@@ -1663,7 +1649,7 @@ void conflict_manager::_process_tag(
         _mysql.run_statement(_tag_update, database::mysql_error::store_tag,
                              conn);
       } else {
-        log_v2::sql()->trace("SQL: add tag {}", tg.id());
+        _logger_sql->trace("SQL: add tag {}", tg.id());
         _tag_insert.bind_value_as_u64(0, tg.id());
         _tag_insert.bind_value_as_u32(1, tg.type());
         _tag_insert.bind_value_as_str(2, tg.name());
@@ -1676,7 +1662,7 @@ void conflict_manager::_process_tag(
           tag_id = future.get();
           _tags_cache[{tg.id(), tg.type()}] = tag_id;
         } catch (const std::exception& e) {
-          log_v2::sql()->error(
+          _logger_sql->error(
               "unified sql: unable to insert new tag ({},{}): {}", tg.id(),
               tg.type(), e.what());
         }
@@ -1684,7 +1670,7 @@ void conflict_manager::_process_tag(
       _add_action(conn, actions::tags);
       break;
     case Tag_Action_MODIFY:
-      log_v2::sql()->trace("SQL: modify tag {}", tg.id());
+      _logger_sql->trace("SQL: modify tag {}", tg.id());
       _tag_update.bind_value_as_u64(0, tg.id());
       _tag_update.bind_value_as_u32(1, tg.type());
       _tag_update.bind_value_as_str(2, tg.name());
@@ -1694,13 +1680,13 @@ void conflict_manager::_process_tag(
                              conn);
         _add_action(conn, actions::tags);
       } else
-        log_v2::sql()->error(
+        _logger_sql->error(
             "unified sql: unable to modify tag ({}, {}): not in cache", tg.id(),
             tg.type());
       break;
       break;
     default:
-      log_v2::sql()->error("Bad action in tag object");
+      _logger_sql->error("Bad action in tag object");
       break;
   }
 }
@@ -1732,8 +1718,8 @@ void conflict_manager::_update_customvariables() {
     std::string query(oss.str());
     _mysql.run_query(query, database::mysql_error::update_customvariables,
                      conn);
-    log_v2::sql()->debug("{} new custom variables inserted", _cv_queue.size());
-    log_v2::sql()->trace("sending query << {} >>", query);
+    _logger_sql->debug("{} new custom variables inserted", _cv_queue.size());
+    _logger_sql->trace("sending query << {} >>", query);
     _add_action(conn, actions::custom_variables);
 
     /* Acknowledgement and cleanup */
@@ -1760,9 +1746,9 @@ void conflict_manager::_update_customvariables() {
     std::string query(oss.str());
     _mysql.run_query(query, database::mysql_error::update_customvariables,
                      conn);
-    log_v2::sql()->debug("{} new custom variable status inserted",
-                         _cvs_queue.size());
-    log_v2::sql()->trace("sending query << {} >>", query);
+    _logger_sql->debug("{} new custom variable status inserted",
+                       _cvs_queue.size());
+    _logger_sql->trace("sending query << {} >>", query);
     _add_action(conn, actions::custom_variables);
 
     /* Acknowledgement and cleanup */
@@ -1782,7 +1768,7 @@ void conflict_manager::_update_customvariables() {
  * When we exit the function, the downtimes queue is empty.
  */
 void conflict_manager::_update_downtimes() {
-  log_v2::sql()->debug("sql: update downtimes");
+  _logger_sql->debug("sql: update downtimes");
   int32_t conn = special_conn::downtime % _mysql.connections_count();
   _finish_action(-1, actions::hosts | actions::instances | actions::downtimes |
                          actions::host_parents | actions::host_dependencies |
@@ -1811,8 +1797,8 @@ void conflict_manager::_update_downtimes() {
     std::string query{oss.str()};
 
     _mysql.run_query(query, database::mysql_error::store_downtime, conn);
-    log_v2::sql()->debug("{} new downtimes inserted", _downtimes_queue.size());
-    log_v2::sql()->trace("sending query << {} >>", query);
+    _logger_sql->debug("{} new downtimes inserted", _downtimes_queue.size());
+    _logger_sql->trace("sending query << {} >>", query);
     _add_action(conn, actions::downtimes);
 
     /* Acknowledgement and cleanup */
@@ -1849,8 +1835,8 @@ void conflict_manager::_insert_logs() {
 
   std::string query(oss.str());
   _mysql.run_query(query, database::mysql_error::update_logs, conn);
-  log_v2::sql()->debug("{} new logs inserted", _log_queue.size());
-  log_v2::sql()->trace("sending query << {} >>", query);
+  _logger_sql->debug("{} new logs inserted", _log_queue.size());
+  _logger_sql->trace("sending query << {} >>", query);
 
   /* Acknowledgement and cleanup */
   while (!_log_queue.empty()) {
