@@ -1,20 +1,20 @@
-/*
-** Copyright 2011-2013,2015 Centreon
-**
-** Licensed under the Apache License, Version 2.0 (the "License");
-** you may not use this file except in compliance with the License.
-** You may obtain a copy of the License at
-**
-**     http://www.apache.org/licenses/LICENSE-2.0
-**
-** Unless required by applicable law or agreed to in writing, software
-** distributed under the License is distributed on an "AS IS" BASIS,
-** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-** See the License for the specific language governing permissions and
-** limitations under the License.
-**
-** For more information : contact@centreon.com
-*/
+/**
+ * Copyright 2011-2013,2015 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ */
 
 #include <pwd.h>
 
@@ -27,15 +27,13 @@ using namespace com::centreon;
 using namespace com::centreon::connector;
 using namespace com::centreon::connector::ssh::sessions;
 
-CCCS_BEGIN()
-namespace sessions {
+namespace com::centreon::connector::ssh::sessions {
 std::ostream& operator<<(std::ostream& os, const session& sess) {
   os << "s this:" << &sess << ' ' << sess.get_credentials();
   return os;
 }
 
-}  // namespace sessions
-CCCS_END()
+}  // namespace com::centreon::connector::ssh::sessions
 
 namespace fmt {
 // formatter specializations for fmt
