@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2019-2021 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -27,7 +27,6 @@
 #include "com/centreon/engine/comment.hh"
 #include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
 
 using namespace com::centreon::engine;
@@ -112,7 +111,7 @@ int command_manager::process_passive_service_check(
         << "Warning:  Passive check result was received for service '"
         << svc_description << "' on host '" << host_name
         << "', but the host could not be found!";
-    log_v2::runtime()->warn(
+    runtime_logger->warn(
         "Warning:  Passive check result was received for service '{}' on host "
         "'{}', but the host could not be found!",
         svc_description, host_name);
@@ -127,7 +126,7 @@ int command_manager::process_passive_service_check(
         << "Warning:  Passive check result was received for service '"
         << svc_description << "' on host '" << host_name
         << "', but the service could not be found!";
-    log_v2::runtime()->warn(
+    runtime_logger->warn(
         "Warning:  Passive check result was received for service '{}' on host "
         "'{}', but the service could not be found!",
         svc_description, host_name);
@@ -138,7 +137,7 @@ int command_manager::process_passive_service_check(
   if (!found->second->passive_checks_enabled())
     return ERROR;
 
-  SPDLOG_LOGGER_DEBUG(log_v2::runtime(),
+  SPDLOG_LOGGER_DEBUG(runtime_logger,
                       "process_passive_service_check check_time={}, "
                       "host_name={}, service={}, return_code={}, output={}",
                       check_time, host_name, svc_description, return_code,
@@ -202,7 +201,7 @@ int command_manager::process_passive_host_check(time_t check_time,
     engine_logger(log_runtime_warning, basic)
         << "Warning:  Passive check result was received for host '" << host_name
         << "', but the host could not be found!";
-    log_v2::runtime()->warn(
+    runtime_logger->warn(
         "Warning:  Passive check result was received for host '{}', but the "
         "host could not be found!",
         host_name);
