@@ -1,33 +1,30 @@
-/*
-** Copyright 2011-2013,2015-2017,2019,2022 Centreon
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 2011-2013,2015-2017,2019-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ *
+ */
 
 #include "com/centreon/engine/configuration/service.hh"
 #include <absl/strings/numbers.h>
 #include <absl/strings/str_split.h>
 #include <absl/strings/string_view.h>
-#include "com/centreon/engine/configuration/serviceextinfo.hh"
-#include "com/centreon/engine/customvariable.hh"
 #include "com/centreon/engine/exceptions/error.hh"
+#include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/host.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
-#include "com/centreon/engine/string.hh"
 
 extern int config_warnings;
 extern int config_errors;
@@ -310,14 +307,14 @@ bool service::operator==(service const& other) const noexcept {
   if (!object::operator==(other)) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => object don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => object don't match");
     return false;
   }
   if (_acknowledgement_timeout != other._acknowledgement_timeout) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "acknowledgement_timeout don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "acknowledgement_timeout don't match");
     return false;
@@ -325,105 +322,105 @@ bool service::operator==(service const& other) const noexcept {
   if (_action_url != other._action_url) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => action_url don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => action_url don't match");
     return false;
   }
   if (_checks_active != other._checks_active) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => checks_active don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => checks_active don't match");
     return false;
   }
   if (_checks_passive != other._checks_passive) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => checks_passive don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => checks_passive don't match");
     return false;
   }
   if (_check_command != other._check_command) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => checks_passive don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => checks_passive don't match");
     return false;
   }
   if (_check_command_is_important != other._check_command_is_important) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => check_command don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => check_command don't match");
     return false;
   }
   if (_check_freshness != other._check_freshness) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => check_freshness don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => check_freshness don't match");
     return false;
   }
   if (_check_interval != other._check_interval) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => check_interval don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => check_interval don't match");
     return false;
   }
   if (_check_period != other._check_period) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => check_period don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => check_period don't match");
     return false;
   }
   if (_contactgroups != other._contactgroups) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => contactgroups don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => contactgroups don't match");
     return false;
   }
   if (_contacts != other._contacts) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => contacts don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => contacts don't match");
     return false;
   }
   if (std::operator!=(_customvariables, other._customvariables)) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => customvariables don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => customvariables don't match");
     return false;
   }
   if (_display_name != other._display_name) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => display_name don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => display_name don't match");
     return false;
   }
   if (_event_handler != other._event_handler) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => event_handler don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => event_handler don't match");
     return false;
   }
   if (_event_handler_enabled != other._event_handler_enabled) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => event_handler don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => event_handler don't match");
     return false;
   }
   if (_first_notification_delay != other._first_notification_delay) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "first_notification_delay don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "first_notification_delay don't match");
     return false;
@@ -431,7 +428,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_flap_detection_enabled != other._flap_detection_enabled) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "flap_detection_enabled don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "flap_detection_enabled don't match");
     return false;
@@ -439,7 +436,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_flap_detection_options != other._flap_detection_options) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "flap_detection_options don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "flap_detection_options don't match");
     return false;
@@ -447,7 +444,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_freshness_threshold != other._freshness_threshold) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "freshness_threshold don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "freshness_threshold don't match");
     return false;
@@ -455,7 +452,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_high_flap_threshold != other._high_flap_threshold) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "high_flap_threshold don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "high_flap_threshold don't match");
     return false;
@@ -463,77 +460,77 @@ bool service::operator==(service const& other) const noexcept {
   if (_hostgroups != other._hostgroups) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => hostgroups don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => hostgroups don't match");
     return false;
   }
   if (_hosts != other._hosts) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => _hosts don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => _hosts don't match");
     return false;
   }
   if (_icon_image != other._icon_image) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => icon_image don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => icon_image don't match");
     return false;
   }
   if (_icon_image_alt != other._icon_image_alt) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => icon_image_alt don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => icon_image_alt don't match");
     return false;
   }
   if (_initial_state != other._initial_state) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => initial_state don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => initial_state don't match");
     return false;
   }
   if (_is_volatile != other._is_volatile) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => is_volatile don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => is_volatile don't match");
     return false;
   }
   if (_low_flap_threshold != other._low_flap_threshold) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => low_flap_threshold don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => low_flap_threshold don't match");
     return false;
   }
   if (_max_check_attempts != other._max_check_attempts) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => max_check_attempts don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => max_check_attempts don't match");
     return false;
   }
   if (_notes != other._notes) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => notes don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => notes don't match");
     return false;
   }
   if (_notes_url != other._notes_url) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => notes_url don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => notes_url don't match");
     return false;
   }
   if (_notifications_enabled != other._notifications_enabled) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "notifications_enabled don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "notifications_enabled don't match");
     return false;
@@ -541,7 +538,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_notification_interval != other._notification_interval) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "notification_interval don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "notification_interval don't match");
     return false;
@@ -549,7 +546,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_notification_options != other._notification_options) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "notification_options don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "notification_options don't match");
     return false;
@@ -557,7 +554,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_notification_period != other._notification_period) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "notification_period don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "notification_period don't match");
     return false;
@@ -565,7 +562,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_obsess_over_service != other._obsess_over_service) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "obsess_over_service don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "obsess_over_service don't match");
     return false;
@@ -573,7 +570,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_process_perf_data != other._process_perf_data) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => process_perf_data don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => process_perf_data don't match");
     return false;
   }
@@ -581,7 +578,7 @@ bool service::operator==(service const& other) const noexcept {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => "
            "retain_nonstatus_information don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "retain_nonstatus_information don't match");
     return false;
@@ -589,7 +586,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_retain_status_information != other._retain_status_information) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "retain_status_information don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "retain_status_information don't match");
     return false;
@@ -597,7 +594,7 @@ bool service::operator==(service const& other) const noexcept {
   if (_retry_interval != other._retry_interval) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => retry_interval don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => retry_interval don't match");
     return false;
   }
@@ -605,7 +602,7 @@ bool service::operator==(service const& other) const noexcept {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => "
            "recovery_notification_delay don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "recovery_notification_delay don't match");
     return false;
@@ -613,14 +610,14 @@ bool service::operator==(service const& other) const noexcept {
   if (_servicegroups != other._servicegroups) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => servicegroups don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => servicegroups don't match");
     return false;
   }
   if (_service_description != other._service_description) {
     engine_logger(dbg_config, more) << "configuration::service::equality => "
                                        "service_description don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => "
         "service_description don't match");
     return false;
@@ -628,54 +625,54 @@ bool service::operator==(service const& other) const noexcept {
   if (_host_id != other._host_id) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => host_id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => host_id don't match");
     return false;
   }
   if (_service_id != other._service_id) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => service_id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => service_id don't match");
     return false;
   }
   if (_stalking_options != other._stalking_options) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => stalking_options don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => stalking_options don't match");
     return false;
   }
   if (_timezone != other._timezone) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => timezone don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => timezone don't match");
     return false;
   }
   if (_severity_id != other._severity_id) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => severity id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => severity id don't match");
     return false;
   }
   if (_icon_id != other._icon_id) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => icon id don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => icon id don't match");
     return false;
   }
   if (_tags != other._tags) {
     engine_logger(dbg_config, more)
         << "configuration::service::equality => tags don't match";
-    log_v2::config()->debug(
+    config_logger->debug(
         "configuration::service::equality => tags don't match");
     return false;
   }
   engine_logger(dbg_config, more) << "configuration::service::equality => OK";
-  log_v2::config()->debug("configuration::service::equality => OK");
+  config_logger->debug("configuration::service::equality => OK");
   return true;
 }
 
@@ -828,19 +825,6 @@ service::key_type service::key() const {
   return k;
 }
 
-/**
- *  Merge object.
- *
- *  @param[in] obj The object to merge.
- */
-void service::merge(configuration::serviceextinfo const& tmpl) {
-  MRG_DEFAULT(_action_url);
-  MRG_DEFAULT(_icon_image);
-  MRG_DEFAULT(_icon_image_alt);
-  MRG_DEFAULT(_notes);
-  MRG_DEFAULT(_notes_url);
-}
-
 /**
  *  Merge object.
  *
@@ -914,7 +898,7 @@ bool service::parse(char const* key, char const* value) {
     return (it->second)(*this, value);
 
   if (key[0] == '_') {
-    map_customvar::iterator it{_customvariables.find(key + 1)};
+    auto it = _customvariables.find(key + 1);
     if (it == _customvariables.end())
       _customvariables[key + 1] = customvariable(value);
     else
@@ -1056,8 +1040,8 @@ bool service::contacts_defined() const noexcept {
  *
  *  @return The customvariables.
  */
-com::centreon::engine::map_customvar const& service::customvariables()
-    const noexcept {
+const std::unordered_map<std::string, customvariable>&
+service::customvariables() const noexcept {
   return _customvariables;
 }
 
@@ -1066,7 +1050,8 @@ com::centreon::engine::map_customvar const& service::customvariables()
  *
  *  @return The customvariables.
  */
-com::centreon::engine::map_customvar& service::customvariables() noexcept {
+std::unordered_map<std::string, customvariable>&
+service::mut_customvariables() noexcept {
   return _customvariables;
 }
 
@@ -1275,7 +1260,6 @@ bool service::notifications_enabled() const noexcept {
  */
 void service::notification_interval(unsigned int interval) noexcept {
   _notification_interval = interval;
-  return;
 }
 
 /**
@@ -1312,7 +1296,6 @@ unsigned short service::notification_options() const noexcept {
  */
 void service::notification_period(std::string const& period) {
   _notification_period = period;
-  return;
 }
 
 /**
@@ -1448,7 +1431,6 @@ unsigned short service::stalking_options() const noexcept {
  */
 void service::timezone(std::string const& time_zone) {
   _timezone = time_zone;
-  return;
 }
 
 /**
@@ -1663,7 +1645,7 @@ bool service::_set_failure_prediction_enabled(bool value) {
   engine_logger(log_verification_error, basic)
       << "Warning: service failure_prediction_enabled is deprecated."
       << " This option will not be supported in 20.04.";
-  log_v2::config()->warn(
+  config_logger->warn(
       "Warning: service failure_prediction_enabled is deprecated. This option "
       "will not be supported in 20.04.");
   ++config_warnings;
@@ -1682,7 +1664,7 @@ bool service::_set_failure_prediction_options(std::string const& value) {
   engine_logger(log_verification_error, basic)
       << "Warning: service failure_prediction_options is deprecated."
       << " This option will not be supported in 20.04.";
-  log_v2::config()->warn(
+  config_logger->warn(
       "Warning: service failure_prediction_options is deprecated. This option "
       "will not be supported in 20.04.");
   ++config_warnings;
@@ -1722,22 +1704,20 @@ bool service::_set_flap_detection_enabled(bool value) {
  */
 bool service::_set_flap_detection_options(std::string const& value) {
   unsigned short options(none);
-  std::list<std::string> values;
-  string::split(value, values, ',');
-  for (std::list<std::string>::iterator it(values.begin()), end(values.end());
-       it != end; ++it) {
-    string::trim(*it);
-    if (*it == "o" || *it == "ok")
+  auto values = absl::StrSplit(value, ',');
+  for (auto& val : values) {
+    auto v = absl::StripAsciiWhitespace(val);
+    if (v == "o" || v == "ok")
       options |= ok;
-    else if (*it == "w" || *it == "warning")
+    else if (v == "w" || v == "warning")
       options |= warning;
-    else if (*it == "u" || *it == "unknown")
+    else if (v == "u" || v == "unknown")
       options |= unknown;
-    else if (*it == "c" || *it == "critical")
+    else if (v == "c" || v == "critical")
       options |= critical;
-    else if (*it == "n" || *it == "none")
+    else if (v == "n" || v == "none")
       options = none;
-    else if (*it == "a" || *it == "all")
+    else if (v == "a" || v == "all")
       options = ok | warning | unknown | critical;
     else
       return false;
@@ -1826,8 +1806,8 @@ bool service::_set_icon_image_alt(std::string const& value) {
  *  @return True on success, otherwise false.
  */
 bool service::_set_initial_state(std::string const& value) {
-  std::string data(value);
-  string::trim(data);
+  std::string_view data(value);
+  data = absl::StripAsciiWhitespace(data);
   if (data == "o" || data == "ok")
     _initial_state = engine::service::state_ok;
   else if (data == "w" || data == "warning")
@@ -1924,26 +1904,24 @@ bool service::_set_notifications_enabled(bool value) {
  */
 bool service::_set_notification_options(std::string const& value) {
   unsigned short options(none);
-  std::list<std::string> values;
-  string::split(value, values, ',');
-  for (std::list<std::string>::iterator it(values.begin()), end(values.end());
-       it != end; ++it) {
-    string::trim(*it);
-    if (*it == "u" || *it == "unknown")
+  auto values = absl::StrSplit(value, ',');
+  for (auto& val : values) {
+    auto v = absl::StripAsciiWhitespace(val);
+    if (v == "u" || v == "unknown")
       options |= unknown;
-    else if (*it == "w" || *it == "warning")
+    else if (v == "w" || v == "warning")
       options |= warning;
-    else if (*it == "c" || *it == "critical")
+    else if (v == "c" || v == "critical")
       options |= critical;
-    else if (*it == "r" || *it == "recovery")
+    else if (v == "r" || v == "recovery")
       options |= ok;
-    else if (*it == "f" || *it == "flapping")
+    else if (v == "f" || v == "flapping")
       options |= flapping;
-    else if (*it == "s" || *it == "downtime")
+    else if (v == "s" || v == "downtime")
       options |= downtime;
-    else if (*it == "n" || *it == "none")
+    else if (v == "n" || v == "none")
       options = none;
-    else if (*it == "a" || *it == "all")
+    else if (v == "a" || v == "all")
       options = unknown | warning | critical | ok | flapping | downtime;
     else
       return false;
@@ -2000,7 +1978,7 @@ bool service::_set_parallelize_check(bool value) {
   engine_logger(log_verification_error, basic)
       << "Warning: service parallelize_check is deprecated"
       << " This option will not be supported in 20.04.";
-  log_v2::config()->warn(
+  config_logger->warn(
       "Warning: service parallelize_check is deprecated This option will not "
       "be supported in 20.04.");
   ++config_warnings;
@@ -2114,22 +2092,20 @@ bool service::set_service_id(uint64_t value) {
  */
 bool service::_set_stalking_options(std::string const& value) {
   unsigned short options(none);
-  std::list<std::string> values;
-  string::split(value, values, ',');
-  for (std::list<std::string>::iterator it(values.begin()), end(values.end());
-       it != end; ++it) {
-    string::trim(*it);
-    if (*it == "o" || *it == "ok")
+  auto values = absl::StrSplit(value, ',');
+  for (auto& val : values) {
+    auto v = absl::StripAsciiWhitespace(val);
+    if (v == "o" || v == "ok")
       options |= ok;
-    else if (*it == "w" || *it == "warning")
+    else if (v == "w" || v == "warning")
       options |= warning;
-    else if (*it == "u" || *it == "unknown")
+    else if (v == "u" || v == "unknown")
       options |= unknown;
-    else if (*it == "c" || *it == "critical")
+    else if (v == "c" || v == "critical")
       options |= critical;
-    else if (*it == "n" || *it == "none")
+    else if (v == "n" || v == "none")
       options = none;
-    else if (*it == "a" || *it == "all")
+    else if (v == "a" || v == "all")
       options = ok | warning | unknown | critical;
     else
       return false;
@@ -2159,7 +2135,7 @@ bool service::_set_timezone(std::string const& value) {
  */
 bool service::_set_category_tags(const std::string& value) {
   bool ret = true;
-  std::list<absl::string_view> tags{absl::StrSplit(value, ',')};
+  std::list<std::string_view> tags{absl::StrSplit(value, ',')};
   for (std::set<std::pair<uint64_t, uint16_t>>::iterator it(_tags.begin()),
        end(_tags.end());
        it != end;) {
@@ -2176,9 +2152,8 @@ bool service::_set_category_tags(const std::string& value) {
     if (parse_ok) {
       _tags.emplace(id, tag::servicecategory);
     } else {
-      log_v2::config()->warn(
-          "Warning: service ({}, {}) error for parsing tag {}", _host_id,
-          _service_id, value);
+      config_logger->warn("Warning: service ({}, {}) error for parsing tag {}",
+                          _host_id, _service_id, value);
       ret = false;
     }
   }
@@ -2194,7 +2169,7 @@ bool service::_set_category_tags(const std::string& value) {
  */
 bool service::_set_group_tags(const std::string& value) {
   bool ret = true;
-  std::list<absl::string_view> tags{absl::StrSplit(value, ',')};
+  std::list<std::string_view> tags{absl::StrSplit(value, ',')};
   for (std::set<std::pair<uint64_t, uint16_t>>::iterator it(_tags.begin()),
        end(_tags.end());
        it != end;) {
@@ -2211,9 +2186,8 @@ bool service::_set_group_tags(const std::string& value) {
     if (parse_ok) {
       _tags.emplace(id, tag::servicegroup);
     } else {
-      log_v2::config()->warn(
-          "Warning: service ({}, {}) error for parsing tag {}", _host_id,
-          _service_id, value);
+      config_logger->warn("Warning: service ({}, {}) error for parsing tag {}",
+                          _host_id, _service_id, value);
       ret = false;
     }
   }
