@@ -1,7 +1,7 @@
 /**
  * Copyright 1999-2009 Ethan Galstad
  * Copyright 2009-2010 Nagios Core Development Team and Community Contributors
- * Copyright 2011-2021 Centreon
+ * Copyright 2011-2024 Centreon
  *
  * This file is part of Centreon Engine.
  *
@@ -23,6 +23,7 @@
 #include <getopt.h>
 #endif  // HAVE_GETOPT_H
 #include <unistd.h>
+#include <forward_list>
 #include <random>
 #include <string>
 
@@ -33,12 +34,17 @@ namespace asio = boost::asio;
 #include <spdlog/fmt/ostr.h>
 #include <spdlog/spdlog.h>
 
+#include <absl/container/btree_map.h>
+
 #include <boost/circular_buffer.hpp>
 #include <boost/container/flat_map.hpp>
-#include <boost/optional.hpp>
+#include <boost/multi_index/member.hpp>
+#include <boost/multi_index/ordered_index.hpp>
+#include <boost/multi_index_container.hpp>
 
 #include <rapidjson/document.h>
 
+#include "com/centreon/common/pool.hh"
 #include "com/centreon/engine/broker.hh"
 #include "com/centreon/engine/broker/loader.hh"
 #include "com/centreon/engine/checks/checker.hh"
@@ -53,7 +59,6 @@ namespace asio = boost::asio;
 #include "com/centreon/engine/enginerpc.hh"
 #include "com/centreon/engine/events/loop.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging.hh"
 #include "com/centreon/engine/logging/broker.hh"
 #include "com/centreon/engine/logging/logger.hh"
@@ -68,12 +73,13 @@ namespace asio = boost::asio;
 #include "com/centreon/engine/version.hh"
 #include "com/centreon/io/directory_entry.hh"
 #include "com/centreon/logging/engine.hh"
+#include "common/log_v2/log_v2.hh"
 
 using namespace com::centreon::engine;
+using com::centreon::common::log_v2::log_v2;
 
 std::shared_ptr<asio::io_context> g_io_context(
     std::make_shared<asio::io_context>());
-bool g_io_context_started = false;
 
 // Error message when configuration parsing fail.
 #define ERROR_CONFIGURATION                                                  \
@@ -112,11 +118,18 @@ int main(int argc, char* argv[]) {
 #endif  // HAVE_GETOPT_H
 
   // Load singletons and global variable.
+  log_v2::load("centengine");
+
+  /* It's time to set the logger. Later, we will have acceses from multiple
+   * threads and we'll only be able to change atomic values. */
   config = new configuration::state;
 
-  // Hack to instanciate the logger.
-  log_v2::load(g_io_context);
+  init_loggers();
   configuration::applier::logging::instance();
+  com::centreon::common::pool::load(g_io_context, runtime_logger);
+
+  config_logger->info("Configuration mechanism used: legacy");
+  config = new configuration::state;
 
   logging::broker backend_broker_log;
 
@@ -169,9 +182,9 @@ int main(int argc, char* argv[]) {
     }
 
     // Invalid argument count.
-    if ((argc < 2)
+    if (argc < 2
         // Main configuration file not on command line.
-        || (optind >= argc))
+        || optind >= argc)
       error = true;
     else {
       // Config file is last argument specified.
@@ -292,8 +305,8 @@ int main(int argc, char* argv[]) {
                   << " services.\n Checked " << timeperiod::timeperiods.size()
                   << " time periods.\n\n Total Warnings: " << config_warnings
                   << "\n Total Errors:   " << config_errors << std::endl;
-        retval = (config_errors ? EXIT_FAILURE : EXIT_SUCCESS);
-      } catch (std::exception const& e) {
+        retval = config_errors ? EXIT_FAILURE : EXIT_SUCCESS;
+      } catch (const std::exception& e) {
         std::cout << "Error while processing a config file: " << e.what()
                   << std::endl;
 
@@ -390,8 +403,8 @@ int main(int argc, char* argv[]) {
           retention::parser p;
           try {
             p.parse(config.state_retention_file(), state);
-          } catch (std::exception const& e) {
-            log_v2::config()->error("{}", e.what());
+          } catch (const std::exception& e) {
+            config_logger->error("{}", e.what());
             engine_logger(logging::log_config_error, logging::basic)
                 << e.what();
           }
@@ -420,12 +433,12 @@ int main(int argc, char* argv[]) {
         com::centreon::logging::engine::instance().add(
             &backend_broker_log, logging::log_all, logging::basic);
 
-        // Apply configuration.
-        configuration::applier::state::instance().apply(config, state);
-
         // Handle signals (interrupts).
         setup_sighandler();
 
+        // Apply configuration.
+        configuration::applier::state::instance().apply(config, state);
+
         // Initialize status data.
         initialize_status_data();
 
@@ -442,20 +455,7 @@ int main(int argc, char* argv[]) {
         broker_program_state(NEBTYPE_PROCESS_EVENTLOOPSTART, NEBFLAG_NONE);
 
         // if neb has not started g_io_context we do it here
-        if (!g_io_context_started) {
-          SPDLOG_LOGGER_INFO(log_v2::process(),
-                             "io_context not started => create thread");
-          std::thread asio_thread([cont = g_io_context]() {
-            try {
-              cont->run();
-            } catch (const std::exception& e) {
-              SPDLOG_LOGGER_CRITICAL(log_v2::process(),
-                                     "catch in io_context run: {}", e.what());
-            }
-          });
-          asio_thread.detach();
-          g_io_context_started = true;
-        }
+        com::centreon::common::pool::set_pool_size(1);
 
         // Get event start time and save as macro.
         event_start = time(NULL);
@@ -463,18 +463,17 @@ int main(int argc, char* argv[]) {
 
         engine_logger(logging::log_info_message, logging::basic)
             << "Event loop start at " << string::ctime(event_start);
-        log_v2::config()->info("Event loop start at {}",
-                               string::ctime(event_start));
+        config_logger->info("Event loop start at {}",
+                            string::ctime(event_start));
         // Start monitoring all services (doesn't return until a
         // restart or shutdown signal is encountered).
         com::centreon::engine::events::loop::instance().run();
 
         if (sigshutdown) {
-          log_v2::instance()->stop_flush_timer();
           engine_logger(logging::log_process_info, logging::basic)
               << "Caught SIG" << sigs[sig_id] << ", shutting down ...";
-          SPDLOG_LOGGER_INFO(log_v2::process(),
-                             "Caught SIG {}, shutting down ...", sigs[sig_id]);
+          SPDLOG_LOGGER_INFO(process_logger, "Caught SIG {}, shutting down ...",
+                             sigs[sig_id]);
         }
         // Send program data to broker.
         broker_program_state(NEBTYPE_PROCESS_EVENTLOOPEND, NEBFLAG_NONE);
@@ -492,7 +491,7 @@ int main(int argc, char* argv[]) {
         if (sigshutdown) {
           engine_logger(logging::log_process_info, logging::basic)
               << "Successfully shutdown ... (PID=" << getpid() << ")";
-          SPDLOG_LOGGER_INFO(log_v2::process(),
+          SPDLOG_LOGGER_INFO(process_logger,
                              "Successfully shutdown ... (PID={})", getpid());
         }
 
@@ -501,7 +500,7 @@ int main(int argc, char* argv[]) {
         // Log.
         engine_logger(logging::log_runtime_error, logging::basic)
             << "Error: " << e.what();
-        SPDLOG_LOGGER_ERROR(log_v2::process(), "Error: {}", e.what());
+        SPDLOG_LOGGER_ERROR(process_logger, "Error: {}", e.what());
         // Send program data to broker.
         broker_program_state(NEBTYPE_PROCESS_SHUTDOWN,
                              NEBFLAG_PROCESS_INITIATED);
@@ -516,12 +515,14 @@ int main(int argc, char* argv[]) {
   } catch (std::exception const& e) {
     engine_logger(logging::log_runtime_error, logging::basic)
         << "Error: " << e.what();
-    SPDLOG_LOGGER_ERROR(log_v2::process(), "Error: {}", e.what());
+    SPDLOG_LOGGER_ERROR(process_logger, "Error: {}", e.what());
   }
 
   // Unload singletons and global objects.
   delete config;
   config = nullptr;
+  g_io_context->stop();
+  com::centreon::common::pool::unload();
 
   return retval;
 }
