@@ -1,22 +1,23 @@
-/*
-** Copyright 1999-2010 Ethan Galstad
-** Copyright 2011-2013 Merethis
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 1999-2010 Ethan Galstad
+ * Copyright 2011-2013 Merethis
+ * Copyright 2014-2024 Centreon
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include "com/centreon/engine/sehandlers.hh"
 #include "com/centreon/engine/broker.hh"
@@ -24,7 +25,6 @@
 #include "com/centreon/engine/downtimes/downtime.hh"
 #include "com/centreon/engine/downtimes/downtime_manager.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
@@ -44,14 +44,14 @@ int obsessive_compulsive_host_check_processor(
     com::centreon::engine::host* hst) {
   std::string raw_command;
   std::string processed_command;
-  int early_timeout = false;
+  bool early_timeout = false;
   double exectime = 0.0;
   int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
   nagios_macros* mac(get_global_macros());
 
   engine_logger(dbg_functions, basic)
       << "obsessive_compulsive_host_check_processor()";
-  log_v2::functions()->trace("obsessive_compulsive_host_check_processor()");
+  functions_logger->trace("obsessive_compulsive_host_check_processor()");
 
   if (hst == nullptr)
     return ERROR;
@@ -80,7 +80,7 @@ int obsessive_compulsive_host_check_processor(
   engine_logger(dbg_checks, most)
       << "Raw obsessive compulsive host processor command line: "
       << raw_command;
-  log_v2::checks()->debug(
+  checks_logger->debug(
       "Raw obsessive compulsive host processor command line: {}", raw_command);
 
   /* process any macros in the raw command line */
@@ -94,33 +94,42 @@ int obsessive_compulsive_host_check_processor(
       << "Processed obsessive compulsive host processor "
          "command line: "
       << processed_command;
-  log_v2::checks()->debug(
+  checks_logger->debug(
       "Processed obsessive compulsive host processor "
       "command line: {}",
       processed_command);
 
-  /* run the command */
-  try {
-    std::string tmp;
-    my_system_r(mac, processed_command, config->ochp_timeout(), &early_timeout,
-                &exectime, tmp, 0);
-  } catch (std::exception const& e) {
-    engine_logger(log_runtime_error, basic)
-        << "Error: can't execute compulsive host processor command line '"
-        << processed_command << "' : " << e.what();
-    log_v2::runtime()->error(
-        "Error: can't execute compulsive host processor command line '{}' : {}",
-        processed_command, e.what());
+  if (hst->command_is_allowed_by_whitelist(processed_command,
+                                           checkable::OBSESS_TYPE)) {
+    /* run the command */
+    try {
+      std::string tmp;
+      my_system_r(mac, processed_command, config->ochp_timeout(),
+                  &early_timeout, &exectime, tmp, 0);
+    } catch (std::exception const& e) {
+      engine_logger(log_runtime_error, basic)
+          << "Error: can't execute compulsive host processor command line '"
+          << processed_command << "' : " << e.what();
+      runtime_logger->error(
+          "Error: can't execute compulsive host processor command line '{}' : "
+          "{}",
+          processed_command, e.what());
+    }
+  } else {
+    runtime_logger->error(
+        "Error: can't execute compulsive host processor command line '{}' : it "
+        "is not allowed by the whitelist",
+        processed_command);
   }
   clear_volatile_macros_r(mac);
 
   /* check to see if the command timed out */
-  if (early_timeout == true)
+  if (early_timeout)
     engine_logger(log_runtime_warning, basic)
         << "Warning: OCHP command '" << processed_command << "' for host '"
         << hst->name() << "' timed out after " << config->ochp_timeout()
         << " seconds";
-  log_v2::runtime()->warn(
+  runtime_logger->warn(
       "Warning: OCHP command '{}' for host '{}' timed out after {} seconds",
       processed_command, hst->name(), config->ochp_timeout());
 
@@ -138,13 +147,13 @@ int run_global_service_event_handler(nagios_macros* mac,
   std::string processed_command;
   std::string processed_logentry;
   std::string command_output;
-  int early_timeout = false;
+  bool early_timeout = false;
   double exectime = 0.0;
   struct timeval start_time;
   int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
 
   engine_logger(dbg_functions, basic) << "run_global_service_event_handler()";
-  log_v2::functions()->trace("run_global_service_event_handler()");
+  functions_logger->trace("run_global_service_event_handler()");
 
   if (svc == nullptr)
     return ERROR;
@@ -160,7 +169,7 @@ int run_global_service_event_handler(nagios_macros* mac,
   engine_logger(dbg_eventhandlers, more)
       << "Running global event handler for service '" << svc->description()
       << "' on host '" << svc->get_hostname() << "'...";
-  log_v2::events()->debug(
+  events_logger->debug(
       "Running global event handler for service '{}' on host '{}'...",
       svc->description(), svc->get_hostname());
 
@@ -177,8 +186,8 @@ int run_global_service_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, most)
       << "Raw global service event handler command line: " << raw_command;
-  log_v2::events()->debug("Raw global service event handler command line: {}",
-                          raw_command);
+  events_logger->debug("Raw global service event handler command line: {}",
+                       raw_command);
 
   /* process any macros in the raw command line */
   process_macros_r(mac, raw_command, processed_command, macro_options);
@@ -189,7 +198,7 @@ int run_global_service_event_handler(nagios_macros* mac,
       << "Processed global service event handler "
          "command line: "
       << processed_command;
-  log_v2::events()->debug(
+  events_logger->debug(
       "Processed global service event handler command line: {}",
       processed_command);
 
@@ -201,31 +210,41 @@ int run_global_service_event_handler(nagios_macros* mac,
         << config->global_service_event_handler();
     process_macros_r(mac, oss.str(), processed_logentry, macro_options);
     engine_logger(log_event_handler, basic) << processed_logentry;
-    log_v2::events()->debug(processed_logentry);
+    events_logger->debug(processed_logentry);
   }
 
-  /* run the command */
-  try {
-    my_system_r(mac, processed_command, config->event_handler_timeout(),
-                &early_timeout, &exectime, command_output, 0);
-  } catch (std::exception const& e) {
-    engine_logger(log_runtime_error, basic)
-        << "Error: can't execute global service event handler "
-           "command line '"
-        << processed_command << "' : " << e.what();
-    log_v2::runtime()->error(
+  static checkable::static_whitelist_last_result cached_cmd;
+
+  if (checkable::command_is_allowed_by_whitelist(processed_command,
+                                                 cached_cmd)) {
+    /* run the command */
+    try {
+      my_system_r(mac, processed_command, config->event_handler_timeout(),
+                  &early_timeout, &exectime, command_output, 0);
+    } catch (std::exception const& e) {
+      engine_logger(log_runtime_error, basic)
+          << "Error: can't execute global service event handler "
+             "command line '"
+          << processed_command << "' : " << e.what();
+      runtime_logger->error(
+          "Error: can't execute global service event handler "
+          "command line '{}' : {}",
+          processed_command, e.what());
+    }
+  } else {
+    runtime_logger->error(
         "Error: can't execute global service event handler "
-        "command line '{}' : {}",
-        processed_command, e.what());
+        "command line '{}' : it is not allowed by the whitelist",
+        processed_command);
   }
 
   /* check to see if the event handler timed out */
-  if (early_timeout == true) {
+  if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Global service event handler command '"
         << processed_command << "' timed out after "
         << config->event_handler_timeout() << " seconds";
-    log_v2::events()->info(
+    events_logger->info(
         "Warning: Global service event handler command '{}' timed out after {} "
         "seconds",
         processed_command, config->event_handler_timeout());
@@ -240,13 +259,13 @@ int run_service_event_handler(nagios_macros* mac,
   std::string processed_command;
   std::string processed_logentry;
   std::string command_output;
-  int early_timeout = false;
+  bool early_timeout = false;
   double exectime = 0.0;
   struct timeval start_time;
   int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
 
   engine_logger(dbg_functions, basic) << "run_service_event_handler()";
-  log_v2::functions()->trace("run_service_event_handler()");
+  functions_logger->trace("run_service_event_handler()");
 
   if (svc == nullptr)
     return ERROR;
@@ -258,9 +277,8 @@ int run_service_event_handler(nagios_macros* mac,
   engine_logger(dbg_eventhandlers, more)
       << "Running event handler for service '" << svc->description()
       << "' on host '" << svc->get_hostname() << "'...";
-  log_v2::events()->debug(
-      "Running event handler for service '{}' on host '{}'...",
-      svc->description(), svc->get_hostname());
+  events_logger->debug("Running event handler for service '{}' on host '{}'...",
+                       svc->description(), svc->get_hostname());
 
   /* get start time */
   gettimeofday(&start_time, nullptr);
@@ -274,8 +292,8 @@ int run_service_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, most)
       << "Raw service event handler command line: " << raw_command;
-  log_v2::events()->debug("Raw service event handler command line: {}",
-                          raw_command);
+  events_logger->debug("Raw service event handler command line: {}",
+                       raw_command);
 
   /* process any macros in the raw command line */
   process_macros_r(mac, raw_command, processed_command, macro_options);
@@ -284,10 +302,10 @@ int run_service_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, most)
       << "Processed service event handler command line: " << processed_command;
-  log_v2::events()->debug("Processed service event handler command line: {}",
-                          processed_command);
+  events_logger->debug("Processed service event handler command line: {}",
+                       processed_command);
 
-  if (config->log_event_handlers() == true) {
+  if (config->log_event_handlers()) {
     std::ostringstream oss;
     oss << "SERVICE EVENT HANDLER: " << svc->get_hostname() << ';'
         << svc->description()
@@ -295,29 +313,37 @@ int run_service_event_handler(nagios_macros* mac,
         << svc->event_handler();
     process_macros_r(mac, oss.str(), processed_logentry, macro_options);
     engine_logger(log_event_handler, basic) << processed_logentry;
-    log_v2::events()->info(processed_logentry);
+    events_logger->info(processed_logentry);
   }
 
-  /* run the command */
-  try {
-    my_system_r(mac, processed_command, config->event_handler_timeout(),
-                &early_timeout, &exectime, command_output, 0);
-  } catch (std::exception const& e) {
-    engine_logger(log_runtime_error, basic)
-        << "Error: can't execute service event handler command line '"
-        << processed_command << "' : " << e.what();
-    log_v2::runtime()->error(
-        "Error: can't execute service event handler command line '{}' : {}",
-        processed_command, e.what());
+  if (svc->command_is_allowed_by_whitelist(processed_command,
+                                           checkable::EVH_TYPE)) {
+    /* run the command */
+    try {
+      my_system_r(mac, processed_command, config->event_handler_timeout(),
+                  &early_timeout, &exectime, command_output, 0);
+    } catch (std::exception const& e) {
+      engine_logger(log_runtime_error, basic)
+          << "Error: can't execute service event handler command line '"
+          << processed_command << "' : " << e.what();
+      runtime_logger->error(
+          "Error: can't execute service event handler command line '{}' : {}",
+          processed_command, e.what());
+    }
+  } else {
+    runtime_logger->error(
+        "Error: can't execute service event handler command line '{}' : it is "
+        "not allowed by the whitelist",
+        processed_command);
   }
 
   /* check to see if the event handler timed out */
-  if (early_timeout == true) {
+  if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Service event handler command '" << processed_command
         << "' timed out after " << config->event_handler_timeout()
         << " seconds";
-    log_v2::events()->info(
+    events_logger->info(
         "Warning: Service event handler command '{}' timed out after {} "
         "seconds",
         processed_command, config->event_handler_timeout());
@@ -334,7 +360,7 @@ int handle_host_event(com::centreon::engine::host* hst) {
   nagios_macros* mac(get_global_macros());
 
   engine_logger(dbg_functions, basic) << "handle_host_event()";
-  log_v2::functions()->trace("handle_host_event()");
+  functions_logger->trace("handle_host_event()");
 
   if (hst == nullptr)
     return ERROR;
@@ -375,13 +401,13 @@ int run_global_host_event_handler(nagios_macros* mac,
   std::string processed_command;
   std::string processed_logentry;
   std::string command_output;
-  int early_timeout = false;
+  bool early_timeout = false;
   double exectime = 0.0;
   struct timeval start_time;
   int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
 
   engine_logger(dbg_functions, basic) << "run_global_host_event_handler()";
-  log_v2::functions()->trace("run_global_host_event_handler()");
+  functions_logger->trace("run_global_host_event_handler()");
 
   if (hst == nullptr)
     return ERROR;
@@ -396,8 +422,8 @@ int run_global_host_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, more)
       << "Running global event handler for host '" << hst->name() << "'...";
-  log_v2::events()->debug("Running global event handler for host '{}'...",
-                          hst->name());
+  events_logger->debug("Running global event handler for host '{}'...",
+                       hst->name());
 
   /* get start time */
   gettimeofday(&start_time, nullptr);
@@ -411,8 +437,8 @@ int run_global_host_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, most)
       << "Raw global host event handler command line: " << raw_command;
-  log_v2::events()->debug("Raw global host event handler command line: {}",
-                          raw_command);
+  events_logger->debug("Raw global host event handler command line: {}",
+                       raw_command);
 
   /* process any macros in the raw command line */
   process_macros_r(mac, raw_command, processed_command, macro_options);
@@ -423,9 +449,8 @@ int run_global_host_event_handler(nagios_macros* mac,
       << "Processed global host event handler "
          "command line: "
       << processed_command;
-  log_v2::events()->debug(
-      "Processed global host event handler command line: {}",
-      processed_command);
+  events_logger->debug("Processed global host event handler command line: {}",
+                       processed_command);
 
   if (config->log_event_handlers() == true) {
     std::ostringstream oss;
@@ -434,29 +459,39 @@ int run_global_host_event_handler(nagios_macros* mac,
         << config->global_host_event_handler();
     process_macros_r(mac, oss.str(), processed_logentry, macro_options);
     engine_logger(log_event_handler, basic) << processed_logentry;
-    log_v2::events()->info(processed_logentry);
+    events_logger->info(processed_logentry);
   }
 
-  /* run the command */
-  try {
-    my_system_r(mac, processed_command, config->event_handler_timeout(),
-                &early_timeout, &exectime, command_output, 0);
-  } catch (std::exception const& e) {
-    engine_logger(log_runtime_error, basic)
-        << "Error: can't execute global host event handler command line '"
-        << processed_command << "' : " << e.what();
-    log_v2::runtime()->error(
-        "Error: can't execute global host event handler command line '{}' : {}",
-        processed_command, e.what());
+  static checkable::static_whitelist_last_result cached_cmd;
+
+  if (host::command_is_allowed_by_whitelist(processed_command, cached_cmd)) {
+    /* run the command */
+    try {
+      my_system_r(mac, processed_command, config->event_handler_timeout(),
+                  &early_timeout, &exectime, command_output, 0);
+    } catch (std::exception const& e) {
+      engine_logger(log_runtime_error, basic)
+          << "Error: can't execute global host event handler command line '"
+          << processed_command << "' : " << e.what();
+      runtime_logger->error(
+          "Error: can't execute global host event handler command line '{}' : "
+          "{}",
+          processed_command, e.what());
+    }
+  } else {
+    runtime_logger->error(
+        "Error: can't execute global host event handler command line '{}' : it "
+        "is not allowed by the whitelist",
+        processed_command);
   }
 
   /* check for a timeout in the execution of the event handler command */
-  if (early_timeout == true) {
+  if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Global host event handler command '" << processed_command
         << "' timed out after " << config->event_handler_timeout()
         << " seconds";
-    log_v2::events()->info(
+    events_logger->info(
         "Warning: Global host event handler command '{}' timed out after {} "
         "seconds",
         processed_command, config->event_handler_timeout());
@@ -472,13 +507,13 @@ int run_host_event_handler(nagios_macros* mac,
   std::string processed_command;
   std::string processed_logentry;
   std::string command_output;
-  int early_timeout = false;
+  bool early_timeout = false;
   double exectime = 0.0;
   struct timeval start_time;
   int macro_options = STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS;
 
   engine_logger(dbg_functions, basic) << "run_host_event_handler()";
-  log_v2::functions()->trace("run_host_event_handler()");
+  functions_logger->trace("run_host_event_handler()");
 
   if (hst == nullptr)
     return ERROR;
@@ -489,8 +524,7 @@ int run_host_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, more)
       << "Running event handler for host '" << hst->name() << "'...";
-  log_v2::events()->debug("Running event handler for host '{}'...",
-                          hst->name());
+  events_logger->debug("Running event handler for host '{}'...", hst->name());
 
   /* get start time */
   gettimeofday(&start_time, nullptr);
@@ -504,8 +538,7 @@ int run_host_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, most)
       << "Raw host event handler command line: " << raw_command;
-  log_v2::events()->debug("Raw host event handler command line: {}",
-                          raw_command);
+  events_logger->debug("Raw host event handler command line: {}", raw_command);
 
   /* process any macros in the raw command line */
   process_macros_r(mac, raw_command, processed_command, macro_options);
@@ -514,8 +547,8 @@ int run_host_event_handler(nagios_macros* mac,
 
   engine_logger(dbg_eventhandlers, most)
       << "Processed host event handler command line: " << processed_command;
-  log_v2::events()->debug("Processed host event handler command line: {}",
-                          processed_command);
+  events_logger->debug("Processed host event handler command line: {}",
+                       processed_command);
 
   if (config->log_event_handlers() == true) {
     std::ostringstream oss;
@@ -524,29 +557,37 @@ int run_host_event_handler(nagios_macros* mac,
         << hst->event_handler();
     process_macros_r(mac, oss.str(), processed_logentry, macro_options);
     engine_logger(log_event_handler, basic) << processed_logentry;
-    log_v2::events()->info(processed_logentry);
+    events_logger->info(processed_logentry);
   }
 
-  /* run the command */
-  try {
-    my_system_r(mac, processed_command, config->event_handler_timeout(),
-                &early_timeout, &exectime, command_output, 0);
-  } catch (std::exception const& e) {
-    engine_logger(log_runtime_error, basic)
-        << "Error: can't execute host event handler command line '"
-        << processed_command << "' : " << e.what();
-    log_v2::runtime()->error(
-        "Error: can't execute host event handler command line '{}' : {}",
-        processed_command, e.what());
+  if (hst->command_is_allowed_by_whitelist(processed_command,
+                                           checkable::EVH_TYPE)) {
+    /* run the command */
+    try {
+      my_system_r(mac, processed_command, config->event_handler_timeout(),
+                  &early_timeout, &exectime, command_output, 0);
+    } catch (std::exception const& e) {
+      engine_logger(log_runtime_error, basic)
+          << "Error: can't execute host event handler command line '"
+          << processed_command << "' : " << e.what();
+      runtime_logger->error(
+          "Error: can't execute host event handler command line '{}' : {}",
+          processed_command, e.what());
+    }
+  } else {
+    runtime_logger->error(
+        "Error: can't execute host event handler command line '{}' : it is not "
+        "allowed by the whitelist",
+        processed_command);
   }
 
   /* check to see if the event handler timed out */
-  if (early_timeout == true) {
+  if (early_timeout) {
     engine_logger(log_event_handler | log_runtime_warning, basic)
         << "Warning: Host event handler command '" << processed_command
         << "' timed out after " << config->event_handler_timeout()
         << " seconds";
-    log_v2::events()->info(
+    events_logger->info(
         "Warning: Host event handler command '{}' timed out after {} seconds",
         processed_command, config->event_handler_timeout());
   }
