@@ -1,21 +1,22 @@
-/*
-** Copyright 2011-2013 Merethis
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 2011-2013 Merethis
+ * Copyright 2014-2024 Centreon
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ * For more information : contact@centreon.com
+ *
+ */
 
 #include "com/centreon/engine/timeperiod.hh"
 #include "com/centreon/engine/broker.hh"
@@ -23,7 +24,6 @@
 #include "com/centreon/engine/daterange.hh"
 #include "com/centreon/engine/exceptions/error.hh"
 #include "com/centreon/engine/globals.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/shared.hh"
 #include "com/centreon/engine/string.hh"
@@ -50,7 +50,7 @@ timeperiod::timeperiod(std::string const& name, std::string const& alias)
   if (name.empty() || alias.empty()) {
     engine_logger(log_config_error, basic)
         << "Error: Name or alias for timeperiod is NULL";
-    log_v2::config()->error("Error: Name or alias for timeperiod is NULL");
+    config_logger->error("Error: Name or alias for timeperiod is NULL");
     throw engine_error() << "Could not register time period '" << name << "'";
   }
 
@@ -59,8 +59,8 @@ timeperiod::timeperiod(std::string const& name, std::string const& alias)
   if (it != timeperiod::timeperiods.end()) {
     engine_logger(log_config_error, basic)
         << "Error: Timeperiod '" << name << "' has already been defined";
-    log_v2::config()->error("Error: Timeperiod '{}' has already been defined",
-                            name);
+    config_logger->error("Error: Timeperiod '{}' has already been defined",
+                         name);
     throw engine_error() << "Could not register time period '" << name << "'";
   }
 }
@@ -755,7 +755,7 @@ static bool _timerange_to_time_t(const timerange& trange,
  */
 bool check_time_against_period(time_t test_time, timeperiod* tperiod) {
   engine_logger(dbg_functions, basic) << "check_time_against_period()";
-  log_v2::functions()->trace("check_time_against_period()");
+  functions_logger->trace("check_time_against_period()");
 
   // If no period was specified, assume the time is good.
   if (!tperiod)
@@ -765,8 +765,8 @@ bool check_time_against_period(time_t test_time, timeperiod* tperiod) {
   time_t next_valid_time{(time_t)-1};
   tperiod->get_next_valid_time_per_timeperiod(test_time, &next_valid_time,
                                               false);
-  log_v2::functions()->trace("check_time_against_period {} ret={}",
-                             tperiod->get_name(), next_valid_time == test_time);
+  functions_logger->trace("check_time_against_period {} ret={}",
+                          tperiod->get_name(), next_valid_time == test_time);
 
   return next_valid_time == test_time;
 }
@@ -784,7 +784,7 @@ bool check_time_against_period_for_notif(time_t test_time,
                                          timeperiod* tperiod) {
   engine_logger(dbg_functions, basic)
       << "check_time_against_period_for_notif()";
-  log_v2::functions()->trace("check_time_against_period_for_notif()");
+  functions_logger->trace("check_time_against_period_for_notif()");
 
   // If no period was specified, assume the time is good.
   if (!tperiod)
@@ -810,7 +810,7 @@ void timeperiod::get_next_invalid_time_per_timeperiod(time_t preferred_time,
                                                       bool notif_timeperiod) {
   engine_logger(dbg_functions, basic)
       << "get_next_invalid_time_per_timeperiod()";
-  log_v2::functions()->trace("get_next_invalid_time_per_timeperiod()");
+  functions_logger->trace("get_next_invalid_time_per_timeperiod()");
 
   // If no time can be found, the original preferred time will be set
   // in invalid_time at the end of the loop.
@@ -995,7 +995,7 @@ void timeperiod::get_next_valid_time_per_timeperiod(time_t preferred_time,
                                                     time_t* valid_time,
                                                     bool notif_timeperiod) {
   engine_logger(dbg_functions, basic) << "get_next_valid_time_per_timeperiod()";
-  log_v2::functions()->trace("get_next_valid_time_per_timeperiod()");
+  functions_logger->trace("get_next_valid_time_per_timeperiod()");
 
   // If no time can be found, the original preferred time will be set
   // in valid_time at the end of the loop.
@@ -1106,9 +1106,8 @@ void timeperiod::get_next_valid_time_per_timeperiod(time_t preferred_time,
   // Else use the calculated time.
   else
     *valid_time = earliest_time;
-  log_v2::functions()->trace(
-      "get_next_valid_time_per_timeperiod {} valid_time={}", _name,
-      *valid_time);
+  functions_logger->trace("get_next_valid_time_per_timeperiod {} valid_time={}",
+                          _name, *valid_time);
 }
 
 /**
@@ -1123,7 +1122,7 @@ void get_next_valid_time(time_t pref_time,
                          time_t* valid_time,
                          timeperiod* tperiod) {
   engine_logger(dbg_functions, basic) << "get_next_valid_time()";
-  log_v2::functions()->trace("get_next_valid_time()");
+  functions_logger->trace("get_next_valid_time()");
 
   // Preferred time must be now or in the future.
   time_t preferred_time(std::max(pref_time, time(NULL)));
@@ -1158,7 +1157,7 @@ void timeperiod::resolve(int& w __attribute__((unused)), int& e) {
     engine_logger(log_verification_error, basic)
         << "Error: The name of time period '" << _name
         << "' contains one or more illegal characters.";
-    log_v2::config()->error(
+    config_logger->error(
         "Error: The name of time period '{}' contains one or more illegal "
         "characters.",
         _name);
@@ -1177,7 +1176,7 @@ void timeperiod::resolve(int& w __attribute__((unused)), int& e) {
           << "Error: Excluded time period '" << it->first
           << "' specified in timeperiod '" << _name
           << "' is not defined anywhere!";
-      log_v2::config()->error(
+      config_logger->error(
           "Error: Excluded time period '{}' specified in timeperiod '{}' is "
           "not defined anywhere!",
           it->first, _name);
