@@ -1,22 +1,22 @@
-/*
-** Copyright 2000-2008 Ethan Galstad
-** Copyright 2011-2013 Merethis
-**
-** This file is part of Centreon Engine.
-**
-** Centreon Engine is free software: you can redistribute it and/or
-** modify it under the terms of the GNU General Public License version 2
-** as published by the Free Software Foundation.
-**
-** Centreon Engine is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-** General Public License for more details.
-**
-** You should have received a copy of the GNU General Public License
-** along with Centreon Engine. If not, see
-** <http://www.gnu.org/licenses/>.
-*/
+/**
+ * Copyright 2000-2008 Ethan Galstad
+ * Copyright 2011-2013 Merethis
+ *
+ * This file is part of Centreon Engine.
+ *
+ * Centreon Engine is free software: you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License version 2
+ * as published by the Free Software Foundation.
+ *
+ * Centreon Engine is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with Centreon Engine. If not, see
+ * <http://www.gnu.org/licenses/>.
+ */
 
 #include "com/centreon/engine/xpddefault.hh"
 #include <fcntl.h>
@@ -26,7 +26,6 @@
 #include "com/centreon/engine/configuration/applier/state.hh"
 #include "com/centreon/engine/globals.hh"
 #include "com/centreon/engine/host.hh"
-#include "com/centreon/engine/log_v2.hh"
 #include "com/centreon/engine/logging/logger.hh"
 #include "com/centreon/engine/macros.hh"
 #include "com/centreon/engine/service.hh"
@@ -99,7 +98,7 @@ int xpddefault_initialize_performance_data() {
           << "Warning: Host performance command '" << temp_command_name
           << "' was not found - host performance data will not "
              "be processed!";
-      log_v2::runtime()->warn(
+      runtime_logger->warn(
           "Warning: Host performance command '{}' was not found - host "
           "performance data will not "
           "be processed!",
@@ -125,7 +124,7 @@ int xpddefault_initialize_performance_data() {
           << "Warning: Service performance command '" << temp_command_name
           << "' was not found - service performance data will not "
              "be processed!";
-      log_v2::runtime()->warn(
+      runtime_logger->warn(
           "Warning: Service performance command '{}' was not found - service "
           "performance data will not "
           "be processed!",
@@ -152,7 +151,7 @@ int xpddefault_initialize_performance_data() {
           << temp_command_name
           << "' was not found - host performance "
              "data file will not be processed!";
-      log_v2::runtime()->warn(
+      runtime_logger->warn(
           "Warning: Host performance file processing command '{}' was not "
           "found - host performance "
           "data file will not be processed!",
@@ -180,7 +179,7 @@ int xpddefault_initialize_performance_data() {
           << temp_command_name
           << "' was not found - service performance "
              "data file will not be processed!";
-      log_v2::runtime()->warn(
+      runtime_logger->warn(
           "Warning: Service performance file processing command '{}' was not "
           "found - service performance "
           "data file will not be processed!",
@@ -292,14 +291,14 @@ int xpddefault_run_service_performance_data_command(
     com::centreon::engine::service* svc) {
   std::string raw_command_line;
   std::string processed_command_line;
-  int early_timeout(false);
+  bool early_timeout = false;
   double exectime;
   int result(OK);
   int macro_options(STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS);
 
   engine_logger(dbg_functions, basic)
       << "run_service_performance_data_command()";
-  log_v2::functions()->trace("run_service_performance_data_command()");
+  functions_logger->trace("run_service_performance_data_command()");
 
   if (svc == nullptr)
     return ERROR;
@@ -317,8 +316,8 @@ int xpddefault_run_service_performance_data_command(
 
   engine_logger(dbg_perfdata, most)
       << "Raw service performance data command line: " << raw_command_line;
-  log_v2::commands()->debug("Raw service performance data command line: {}",
-                            raw_command_line);
+  commands_logger->debug("Raw service performance data command line: {}",
+                         raw_command_line);
 
   // process any macros in the raw command line.
   process_macros_r(mac, raw_command_line, processed_command_line,
@@ -329,9 +328,8 @@ int xpddefault_run_service_performance_data_command(
   engine_logger(dbg_perfdata, most) << "Processed service performance data "
                                        "command line: "
                                     << processed_command_line;
-  log_v2::commands()->debug(
-      "Processed service performance data command line: {}",
-      processed_command_line);
+  commands_logger->debug("Processed service performance data command line: {}",
+                         processed_command_line);
 
   // run the command.
   try {
@@ -342,19 +340,19 @@ int xpddefault_run_service_performance_data_command(
     engine_logger(log_runtime_error, basic)
         << "Error: can't execute service performance data command line '"
         << processed_command_line << "' : " << e.what();
-    log_v2::runtime()->error(
+    runtime_logger->error(
         "Error: can't execute service performance data command line '{}' : {}",
         processed_command_line, e.what());
   }
 
   // check to see if the command timed out.
-  if (early_timeout == true)
+  if (early_timeout)
     engine_logger(log_runtime_warning, basic)
         << "Warning: Service performance data command '"
         << processed_command_line << "' for service '" << svc->description()
         << "' on host '" << svc->get_hostname() << "' timed out after "
         << config->perfdata_timeout() << " seconds";
-  log_v2::runtime()->warn(
+  runtime_logger->warn(
       "Warning: Service performance data command '{}' for service '{}' on host "
       "'{}' timed out after {} seconds",
       processed_command_line, svc->description(), svc->get_hostname(),
@@ -368,13 +366,13 @@ int xpddefault_run_host_performance_data_command(nagios_macros* mac,
                                                  host* hst) {
   std::string raw_command_line;
   std::string processed_command_line;
-  int early_timeout(false);
+  bool early_timeout = false;
   double exectime;
   int result(OK);
   int macro_options(STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS);
 
   engine_logger(dbg_functions, basic) << "run_host_performance_data_command()";
-  log_v2::functions()->trace("run_host_performance_data_command()");
+  functions_logger->trace("run_host_performance_data_command()");
 
   if (hst == nullptr)
     return ERROR;
@@ -392,8 +390,8 @@ int xpddefault_run_host_performance_data_command(nagios_macros* mac,
 
   engine_logger(dbg_perfdata, most)
       << "Raw host performance data command line: " << raw_command_line;
-  log_v2::commands()->info("Raw host performance data command line: {}",
-                           raw_command_line);
+  commands_logger->info("Raw host performance data command line: {}",
+                        raw_command_line);
 
   // process any macros in the raw command line.
   process_macros_r(mac, raw_command_line, processed_command_line,
@@ -402,8 +400,8 @@ int xpddefault_run_host_performance_data_command(nagios_macros* mac,
   engine_logger(dbg_perfdata, most)
       << "Processed host performance data command line: "
       << processed_command_line;
-  log_v2::commands()->info("Processed host performance data command line: {}",
-                           processed_command_line);
+  commands_logger->info("Processed host performance data command line: {}",
+                        processed_command_line);
 
   // run the command.
   try {
@@ -414,7 +412,7 @@ int xpddefault_run_host_performance_data_command(nagios_macros* mac,
     engine_logger(log_runtime_error, basic)
         << "Error: can't execute host performance data command line '"
         << processed_command_line << "' : " << e.what();
-    log_v2::runtime()->error(
+    runtime_logger->error(
         "Error: can't execute host performance data command line '{}' : {}",
         processed_command_line, e.what());
   }
@@ -423,12 +421,12 @@ int xpddefault_run_host_performance_data_command(nagios_macros* mac,
     return ERROR;
 
   // check to see if the command timed out.
-  if (early_timeout == true)
+  if (early_timeout)
     engine_logger(log_runtime_warning, basic)
         << "Warning: Host performance data command '" << processed_command_line
         << "' for host '" << hst->name() << "' timed out after "
         << config->perfdata_timeout() << " seconds";
-  log_v2::runtime()->warn(
+  runtime_logger->warn(
       "Warning: Host performance data command '{}' for host '{}' timed out "
       "after {} seconds",
       processed_command_line, hst->name(), config->perfdata_timeout());
@@ -460,7 +458,7 @@ int xpddefault_open_host_perfdata_file() {
           << "Warning: File '" << xpddefault_host_perfdata_fp
           << "' could not be opened - host performance data will not "
              "be written to file!";
-      log_v2::runtime()->warn(
+      runtime_logger->warn(
           "Warning: File '{}' could not be opened - host performance data will "
           "not "
           "be written to file!",
@@ -496,7 +494,7 @@ int xpddefault_open_service_perfdata_file() {
           << "Warning: File '" << config->service_perfdata_file()
           << "' could not be opened - service performance data will not "
              "be written to file!";
-      log_v2::runtime()->warn(
+      runtime_logger->warn(
           "Warning: File '{}' could not be opened - service performance data "
           "will not "
           "be written to file!",
@@ -574,7 +572,7 @@ int xpddefault_update_service_performance_data_file(
 
   engine_logger(dbg_functions, basic)
       << "update_service_performance_data_file()";
-  log_v2::functions()->trace("update_service_performance_data_file()");
+  functions_logger->trace("update_service_performance_data_file()");
 
   if (svc == nullptr)
     return ERROR;
@@ -589,8 +587,8 @@ int xpddefault_update_service_performance_data_file(
 
   engine_logger(dbg_perfdata, most)
       << "Raw service performance data file output: " << raw_output;
-  log_v2::commands()->info("Raw service performance data file output: {}",
-                           raw_output);
+  commands_logger->info("Raw service performance data file output: {}",
+                        raw_output);
 
   // process any macros in the raw output line.
   process_macros_r(mac, raw_output, processed_output, 0);
@@ -599,8 +597,8 @@ int xpddefault_update_service_performance_data_file(
 
   engine_logger(dbg_perfdata, most)
       << "Processed service performance data file output: " << processed_output;
-  log_v2::commands()->info("Processed service performance data file output: {}",
-                           processed_output);
+  commands_logger->info("Processed service performance data file output: {}",
+                        processed_output);
 
   // lock, write to and unlock host performance data file.
   pthread_mutex_lock(&xpddefault_service_perfdata_fp_lock);
@@ -620,7 +618,7 @@ int xpddefault_update_host_performance_data_file(nagios_macros* mac,
   int result(OK);
 
   engine_logger(dbg_functions, basic) << "update_host_performance_data_file()";
-  log_v2::functions()->trace("update_host_performance_data_file()");
+  functions_logger->trace("update_host_performance_data_file()");
 
   if (hst == nullptr)
     return ERROR;
@@ -635,7 +633,7 @@ int xpddefault_update_host_performance_data_file(nagios_macros* mac,
 
   engine_logger(dbg_perfdata, most)
       << "Raw host performance file output: " << raw_output;
-  log_v2::commands()->info("Raw host performance file output: {}", raw_output);
+  commands_logger->info("Raw host performance file output: {}", raw_output);
 
   // process any macros in the raw output.
   process_macros_r(mac, raw_output, processed_output, 0);
@@ -644,8 +642,8 @@ int xpddefault_update_host_performance_data_file(nagios_macros* mac,
 
   engine_logger(dbg_perfdata, most)
       << "Processed host performance data file output: " << processed_output;
-  log_v2::commands()->info("Processed host performance data file output: {}",
-                           processed_output);
+  commands_logger->info("Processed host performance data file output: {}",
+                        processed_output);
 
   // lock, write to and unlock host performance data file.
   pthread_mutex_lock(&xpddefault_host_perfdata_fp_lock);
@@ -661,14 +659,14 @@ int xpddefault_update_host_performance_data_file(nagios_macros* mac,
 int xpddefault_process_host_perfdata_file() {
   std::string raw_command_line;
   std::string processed_command_line;
-  int early_timeout(false);
+  bool early_timeout = false;
   double exectime(0.0);
   int result(OK);
   int macro_options(STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS);
   nagios_macros* mac(get_global_macros());
 
   engine_logger(dbg_functions, basic) << "process_host_perfdata_file()";
-  log_v2::functions()->trace("process_host_perfdata_file()");
+  functions_logger->trace("process_host_perfdata_file()");
 
   // we don't have a command.
   if (config->host_perfdata_file_processing_command().empty())
@@ -687,7 +685,7 @@ int xpddefault_process_host_perfdata_file() {
   engine_logger(dbg_perfdata, most)
       << "Raw host performance data file processing command line: "
       << raw_command_line;
-  log_v2::commands()->info(
+  commands_logger->info(
       "Raw host performance data file processing command line: {}",
       raw_command_line);
 
@@ -703,7 +701,7 @@ int xpddefault_process_host_perfdata_file() {
       << "Processed host performance data file processing command "
          "line: "
       << processed_command_line;
-  log_v2::commands()->info(
+  commands_logger->info(
       "Processed host performance data file processing command line: {}",
       processed_command_line);
 
@@ -721,7 +719,7 @@ int xpddefault_process_host_perfdata_file() {
         << "Error: can't execute host performance data file processing command "
            "line '"
         << processed_command_line << "' : " << e.what();
-    log_v2::runtime()->error(
+    runtime_logger->error(
         "Error: can't execute host performance data file processing command "
         "line '{}' : {}",
         processed_command_line, e.what());
@@ -733,12 +731,12 @@ int xpddefault_process_host_perfdata_file() {
   pthread_mutex_unlock(&xpddefault_host_perfdata_fp_lock);
 
   // check to see if the command timed out.
-  if (early_timeout == true)
+  if (early_timeout)
     engine_logger(log_runtime_warning, basic)
         << "Warning: Host performance data file processing command '"
         << processed_command_line << "' timed out after "
         << config->perfdata_timeout() << " seconds";
-  log_v2::runtime()->warn(
+  runtime_logger->warn(
       "Warning: Host performance data file processing command '{}' timed out "
       "after {} seconds",
       processed_command_line, config->perfdata_timeout());
@@ -749,14 +747,14 @@ int xpddefault_process_host_perfdata_file() {
 int xpddefault_process_service_perfdata_file() {
   std::string raw_command_line;
   std::string processed_command_line;
-  int early_timeout(false);
+  bool early_timeout = false;
   double exectime(0.0);
   int result(OK);
   int macro_options(STRIP_ILLEGAL_MACRO_CHARS | ESCAPE_MACRO_CHARS);
   nagios_macros* mac(get_global_macros());
 
   engine_logger(dbg_functions, basic) << "process_service_perfdata_file()";
-  log_v2::functions()->trace("process_service_perfdata_file()");
+  functions_logger->trace("process_service_perfdata_file()");
 
   // we don't have a command.
   if (config->service_perfdata_file_processing_command().empty())
@@ -776,7 +774,7 @@ int xpddefault_process_service_perfdata_file() {
       << "Raw service performance data file processing "
          "command line: "
       << raw_command_line;
-  log_v2::commands()->info(
+  commands_logger->info(
       "Raw service performance data file processing command line: {}",
       raw_command_line);
 
@@ -792,7 +790,7 @@ int xpddefault_process_service_perfdata_file() {
       << "Processed service performance data file processing "
          "command line: "
       << processed_command_line;
-  log_v2::commands()->info(
+  commands_logger->info(
       "Processed service performance data file processing command line: {}",
       processed_command_line);
 
@@ -810,7 +808,7 @@ int xpddefault_process_service_perfdata_file() {
         << "Error: can't execute service performance data file processing "
            "command line '"
         << processed_command_line << "' : " << e.what();
-    log_v2::runtime()->error(
+    runtime_logger->error(
         "Error: can't execute service performance data file processing "
         "command line '{}' : {}",
         processed_command_line, e.what());
@@ -823,12 +821,12 @@ int xpddefault_process_service_perfdata_file() {
   clear_volatile_macros_r(mac);
 
   // check to see if the command timed out.
-  if (early_timeout == true)
+  if (early_timeout)
     engine_logger(log_runtime_warning, basic)
         << "Warning: Service performance data file processing command '"
         << processed_command_line << "' timed out after "
         << config->perfdata_timeout() << " seconds";
-  log_v2::runtime()->warn(
+  runtime_logger->warn(
       "Warning: Service performance data file processing command '{}' timed "
       "out after {} seconds",
       processed_command_line, config->perfdata_timeout());
