@@ -1,4 +1,4 @@
-/*
+/**
  * Copyright 2020 Centreon (https://www.centreon.com/)
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -37,7 +37,7 @@
 #include "com/centreon/engine/configuration/host.hh"
 #include "com/centreon/engine/configuration/service.hh"
 #include "com/centreon/engine/exceptions/error.hh"
-#include "com/centreon/engine/log_v2.hh"
+#include "com/centreon/engine/globals.hh"
 #include "helper.hh"
 
 using namespace com::centreon;
@@ -48,10 +48,11 @@ using namespace com::centreon::engine::configuration::applier;
 class AnomalydetectionCheck : public TestEngine {
  public:
   void SetUp() override {
+    ::unlink("/tmp/thresholds_status_change.json");
     init_config_state();
 
-    log_v2::checks()->set_level(spdlog::level::trace);
-    log_v2::commands()->set_level(spdlog::level::trace);
+    checks_logger->set_level(spdlog::level::trace);
+    commands_logger->set_level(spdlog::level::trace);
 
     configuration::applier::contact ct_aply;
     configuration::contact ctct{new_configuration_contact("admin", true)};
@@ -1061,6 +1062,8 @@ TEST_P(AnomalydetectionCheckFileTooOld, FileTooOld) {
   ASSERT_EQ(_ad->get_perf_data(), "metric=70%;50;75");
 
   ::unlink("/tmp/thresholds_status_change.json");
+  // let's time to callback to be called
+  std::this_thread::sleep_for(std::chrono::milliseconds(10));
 }
 
 INSTANTIATE_TEST_SUITE_P(
